clc; clear; close all; set(0,'DefaultFigureVisible','on')

% Specify what we're looking for right here up top
baseDatasetFileName = '../chassData/chassNoisy.mat';
dataDir = 'output_bfSweep';
fileNameStem = 'impulseSweep_iterK=';

            

fprintf('Analyzing bf on ''%s''...\n',baseDatasetFileName);

% Pull the master dataset
baseDataset = load(baseDatasetFileName);
metabNameList = baseDataset.colNames;
noiseCoV = baseDataset.CoV;
noisyDataMatrix = baseDataset.noisyDataMatrix;

% Get time arrays
sampleTime = baseDataset.sampleTime;
smoothTime = baseDataset.smoothTime;
smoothTimeDeriv = baseDataset.derivSmoothTime;
hdTime = linspace(sampleTime(1),sampleTime(end),(length(sampleTime)-1)*10+1)';

% Get our true data arrays
[~, hdIdxConc] = min(abs(repmat(smoothTime,1,size(hdTime,1))-repmat(hdTime',size(smoothTime,1),1)));
[~, hdIdxDeriv] = min(abs(repmat(smoothTimeDeriv,1,size(hdTime,1))-repmat(hdTime',size(smoothTimeDeriv,1),1)));

trueConcSmooth = baseDataset.trueData;
trueDerivSmooth = baseDataset.trueDataDeriv;
trueConcSample = baseDataset.noiselessData;
trueDerivSample = baseDataset.trueDataDeriv(baseDataset.idxSampleDeriv,:);
trueConcHd = baseDataset.trueData(hdIdxConc,:);
trueDerivHd = baseDataset.trueDataDeriv(hdIdxDeriv,:);

% Final clean-up/set-up
clear baseDataset


set_k = 1;
fileList = dir(dataDir);

for i = 1:length(fileList);
    
    if length(fileNameStem) < length(fileList(i).name) && strcmp(fileNameStem,fileList(i).name(1:length(fileNameStem)))
        
        fileName = fileList(i).name;
    
        % Which file are we checking right now?
        fprintf('\tReading Set %02d\n',set_k);

        % More robust handling for when cases screw up
        try

            % Get the parameters for this particlar function & metabolite
            load(sprintf('%s/%s',dataDir,fileName));

            % Record info about which function and metabolite we're
            % looking at, for future reference
            currentFunc{set_k} = funcType;
            currentMetabNum(set_k) = metab_j;
            currentMetabName{set_k} = metabNameList{metab_j};
            hFList(set_k) = hF;
            bFList(set_k) = bF;
            rmsdList{set_k} = directRmsd;
            rmsdMatrix(:,set_k) = directRmsd(:);


            % Now let's get cracking
            directConcSample = zeros(length(sampleTime),numIters);
            directConcHd = zeros(length(hdTime),numIters);
            directConcSmooth = zeros(length(smoothTime),numIters);
            directDerivSample = zeros(length(sampleTime),numIters);
            directDerivHd = zeros(length(hdTime),numIters);
            directDerivSmooth = zeros(length(smoothTimeDeriv),numIters);

            % We're calculated the parameters elsewhere:
            % Regenerate time courses for the direct fit
            for noisySet_k = 1:numIters
                directConcSample(:,noisySet_k) = evalSmoothingFcn(directParamSolution(:,noisySet_k),sampleTime,currentFunc{set_k});
                directConcHd(:,noisySet_k) = evalSmoothingFcn(directParamSolution(:,noisySet_k),hdTime,currentFunc{set_k});
                directConcSmooth(:,noisySet_k) = evalSmoothingFcn(directParamSolution(:,noisySet_k),smoothTime,currentFunc{set_k});
                directDerivSample(:,noisySet_k) = evalSmoothingDeriv(directParamSolution(:,noisySet_k),sampleTime,currentFunc{set_k});
                directDerivHd(:,noisySet_k) = evalSmoothingDeriv(directParamSolution(:,noisySet_k),hdTime,currentFunc{set_k});
                directDerivSmooth(:,noisySet_k) = evalSmoothingDeriv(directParamSolution(:,noisySet_k),smoothTimeDeriv,currentFunc{set_k});
            end


            % Some scaling and penalty factors for our metrics
            denominator = length(sampleTime)-nnz(~isnan(directParamSolution(:,1)));
            hdDenom = length(hdTime) * ((length(sampleTime)-nnz(~isnan(directParamSolution(:,1))))/length(sampleTime));

            concScaleSample = sqrt(mean((trueConcSample(:,metab_j)).^2));
            derivScaleSample = sqrt(mean((trueDerivSample(:,metab_j)).^2));
            concScaleHd = sqrt(mean((trueConcHd(:,metab_j)).^2));
            derivScaleHd = sqrt(mean((trueDerivHd(:,metab_j)).^2));

            % Error metrics
            directConcAccHd{set_k} = sqrt(sum((directConcHd - repmat(trueConcHd(:,metab_j),1,numIters)).^2,1))/(hdDenom*concScaleHd);
            directDerivAccHd{set_k} = sqrt(sum((directDerivHd - repmat(trueDerivHd(:,metab_j),1,numIters)).^2,1))/(hdDenom*derivScaleHd);

            % Some of the plot methods are interested in the medians of the metrics
            medianDirectConcAccHd(set_k) = median(directConcAccHd{set_k},2);
            medianDirectDerivAccHd(set_k) = median(directDerivAccHd{set_k},2);

            % How consistent are my fits? --> Robustness of performance
            directConcDispersion(set_k) = median(sqrt(sum(((directConcHd - repmat(median(directConcHd,2),1,numIters)).^2)/hdDenom,1))/concScaleHd);
            directDerivDispersion(set_k) = median(sqrt(sum(((directDerivHd - repmat(median(directDerivHd,2),1,numIters)).^2)/hdDenom,1))/derivScaleHd);
            directConcRobustness(set_k) = mean(sqrt(sum(((directConcHd - repmat(median(directConcHd,2),1,numIters)).^2)/hdDenom,1))/concScaleHd);
            directDerivRobustness(set_k) = mean(sqrt(sum(((directDerivHd - repmat(median(directDerivHd,2),1,numIters)).^2)/hdDenom,1))/derivScaleHd);

            set_k = set_k + 1;

        catch
            fprintf('\tWarning: Error during analysis of ''%s/%s''\n',dataDir,fileName);
        end
    end
end

save sweepBfChass

% We have everything we need to plot Metrics
try
    plotMetricsVsBf
end
