clc; clear; close all; set(0,'DefaultFigureVisible','on')

% What files are we importing in?
sampleDataFile = 'chassNoiseless.txt';
smoothDataFile = 'chassTrue.txt';

% Define our noisy dataset
numIters = 500;
CoV = .15;
numReplicates = 5;
timeUnit = 'sec';
concUnit = 'mM';


% Just some annotation/record keeping:

% Order of metabolites in the original file
% 1	'# Time'
% 2	'"Extracellular Glucose"'
% 3	'"Phosphoenol pyruvate"'
% 4	'Glucose-6-Phosphate'
% 5	'Pyruvate'
% 6	'Fructose-6-Phosphate'
% 7	'Glucose-1-Phosphate'
% 8	'6-Phosphogluconate'
% 9	'Fructose-1,6-bisphosphate'
% 10	'sedoheptulose-7-phosphate'
% 11	'Glyceraldehyde-3-Phosphate'
% 12	'Erythrose-4-phosphate'
% 13	'Xylulose-5-phosphate'
% 14	'Ribose-5-phosphate'
% 15	'Dihydroxyacetonephosphate'
% 16	'1,3-diphosphosphoglycerate'
% 17	'3-Phosphoglycerate'
% 18	'2-Phosphoglycerate'
% 19	'Ribulose-5-phosphate'
% 20	'Compartments[extracellular]'
% 21	'Compartments[cytosol]'
% 22	'Values[catp]'
% 23	'Values[cadp]'
% 24	'Values[camp]'
% 25	'Values[cnadp]'
% 26	'Values[cnadph]'
% 27	'Values[cnad]'
% 28	'Values[cnadh]'

% Order of graphs in the paper
columnList = [2, 4, 6, 9, 15, 11, 16, 17, 18, 3, 5, 8, 19, 13, 10, 14, 12, 7];

% 2	'"Extracellular Glucose"'
% 4	'Glucose-6-Phosphate'
% 6	'Fructose-6-Phosphate'
% 9	'Fructose-1,6-bisphosphate'
% 15	'Dihydroxyacetonephosphate'
% 11	'Glyceraldehyde-3-Phosphate'
% 16	'1,3-diphosphosphoglycerate'
% 17	'3-Phosphoglycerate'
% 18	'2-Phosphoglycerate'
% 3	'"Phosphoenol pyruvate"'
% 5	'Pyruvate'
% 8	'6-Phosphogluconate'
% 19	'Ribulose-5-phosphate'
% 13	'Xylulose-5-phosphate'
% 10	'sedoheptulose-7-phosphate'
% 14	'Ribose-5-phosphate'
% 12	'Erythrose-4-phosphate'
% 7	'Glucose-1-Phosphate'


% Load in our data
dataStruct = importdata(sampleDataFile);
    noiselessData = dataStruct.data(:,columnList);
    sampleTime = dataStruct.data(:,1);
dataStruct = importdata(smoothDataFile);
    trueData = dataStruct.data(:,columnList);
    smoothTime = dataStruct.data(:,1);
    colNames = dataStruct.colheaders(columnList)';

% Take the derivative of the true, smooth data (Finite Difference Approx)
trueDataDeriv = (trueData(3:end,:) - trueData(1:end-2,:))./repmat((smoothTime(3:end) - smoothTime(1:end-2)),1,size(trueData,2));
derivSmoothTime = smoothTime(2:end-1);

% Get the derivative values at our sample times
[~, idxSampleDeriv] = min(abs(repmat(derivSmoothTime,1,size(sampleTime,1))-repmat(sampleTime',size(derivSmoothTime,1),1)));
noiselessDataDeriv = trueDataDeriv(idxSampleDeriv,:);


noisyDataMatrix = repmat({zeros(size(noiselessData))},numIters,1);

for iteration_k = 1:numIters

    % Reinitialize storage space...
    noisyData = zeros(size(noiselessData,1),size(noiselessData,2),numReplicates);

    % Generate the noisy measurements
    for j=1:size(noiselessData,2)
        for i = 1:size(noiselessData,1)

            for k = 1:numReplicates
                % Add noise to the original measurements
                noisyData(i,j,k) = CoV*noiselessData(i,j)*randn(1,1) + noiselessData(i,j);
            end

            % Get the average of the noisy data
            noisyDataMatrix{iteration_k}(i,j) = mean(noisyData(i,j,:));

        end
    end

end

% Save our results out
save('chassNoisy.mat',...
     'numIters',...
     'CoV',...
     'numReplicates',...
     'timeUnit',...
     'concUnit',...
     'colNames',...
     'trueData',...
     'trueDataDeriv',...
     'noiselessData',...
     'noiselessDataDeriv',...
     'noisyDataMatrix',...
     'sampleTime',...
     'smoothTime',...
     'derivSmoothTime',...
     'idxSampleDeriv');
