clc; clear; close all; set(0,'DefaultFigureVisible','on')

% What files are we importing in?
sampleDataFile = 'chassNoiseless.txt';
smoothDataFile = 'chassTrue.txt';

% Define our noisy dataset
metabList = 2:18;
numResampleIters = 250;
numRandIters = 50;
CoV = .15;
numReplicates = 5;
timeUnit = 'sec';
concUnit = 'mM';


% Just some annotation/record keeping:

% Order of metabolites in the original file
% 1	'# Time'
% 2	'"Extracellular Glucose"'
% 3	'"Phosphoenol pyruvate"'
% 4	'Glucose-6-Phosphate'
% 5	'Pyruvate'
% 6	'Fructose-6-Phosphate'
% 7	'Glucose-1-Phosphate'
% 8	'6-Phosphogluconate'
% 9	'Fructose-1,6-bisphosphate'
% 10	'sedoheptulose-7-phosphate'
% 11	'Glyceraldehyde-3-Phosphate'
% 12	'Erythrose-4-phosphate'
% 13	'Xylulose-5-phosphate'
% 14	'Ribose-5-phosphate'
% 15	'Dihydroxyacetonephosphate'
% 16	'1,3-diphosphosphoglycerate'
% 17	'3-Phosphoglycerate'
% 18	'2-Phosphoglycerate'
% 19	'Ribulose-5-phosphate'
% 20	'Compartments[extracellular]'
% 21	'Compartments[cytosol]'
% 22	'Values[catp]'
% 23	'Values[cadp]'
% 24	'Values[camp]'
% 25	'Values[cnadp]'
% 26	'Values[cnadph]'
% 27	'Values[cnad]'
% 28	'Values[cnadh]'

% %     medianIters = 10;
% %     numRandIters = 3;
% %     CoV = .15;
% %     numReplicates = 5;

% Order of graphs in the paper
columnList = [2, 4, 6, 9, 15, 11, 16, 17, 18, 3, 5, 8, 19, 13, 10, 14, 12, 7];

% 2	'"Extracellular Glucose"'
% 4	'Glucose-6-Phosphate'
% 6	'Fructose-6-Phosphate'
% 9	'Fructose-1,6-bisphosphate'
% 15	'Dihydroxyacetonephosphate'
% 11	'Glyceraldehyde-3-Phosphate'
% 16	'1,3-diphosphosphoglycerate'
% 17	'3-Phosphoglycerate'
% 18	'2-Phosphoglycerate'
% 3	'"Phosphoenol pyruvate"'
% 5	'Pyruvate'
% 8	'6-Phosphogluconate'
% 19	'Ribulose-5-phosphate'
% 13	'Xylulose-5-phosphate'
% 10	'sedoheptulose-7-phosphate'
% 14	'Ribose-5-phosphate'
% 12	'Erythrose-4-phosphate'
% 7	'Glucose-1-Phosphate'


% Load in our data
dataStruct = importdata(sampleDataFile);
    noiselessDataAll = dataStruct.data(:,columnList);
    sampleTime = dataStruct.data(:,1);
dataStruct = importdata(smoothDataFile);
    trueDataAll = dataStruct.data(:,columnList);
    smoothTime = dataStruct.data(:,1);
    colNames = dataStruct.colheaders(columnList)';

clear dataStruct

% Take the derivative of the true, smooth data (Finite Difference Approx)
trueDataDerivAll = (trueDataAll(3:end,:) - trueDataAll(1:end-2,:))./repmat((smoothTime(3:end) - smoothTime(1:end-2)),1,size(trueDataAll,2));
derivSmoothTime = smoothTime(2:end-1);

[~, idxSampleDeriv] = min(abs(repmat(derivSmoothTime,1,size(sampleTime,1))-repmat(sampleTime',size(derivSmoothTime,1),1)));
noiselessDataDerivAll = trueDataDerivAll(idxSampleDeriv,:);



for metab_j = metabList;

    metabNum = metab_j;
    
    % Base underlying data
    trueData = repmat(trueDataAll(:,metab_j),1,numRandIters);
    trueDataDeriv = repmat(trueDataDerivAll(:,metab_j),1,numRandIters);
    noiselessData = repmat(noiselessDataAll(:,metab_j),1,numRandIters);
    noiselessDataDeriv = repmat(noiselessDataDerivAll(:,metab_j),1,numRandIters);
 
    
    % Generate the noisy datasets
    baseNoisyData = zeros(size(noiselessDataAll,1),numRandIters);
    
    for iteration_k = 1:numRandIters

        % Reinitialize storage space...
        noisyDataGen = zeros(size(noiselessDataAll,1),numReplicates);

        % Generate the noisy measurements
        for j=1:numRandIters
            for i = 1:size(noiselessDataAll,1)

                for k = 1:numReplicates
                    % Add noise to the original measurements
                    noisyDataGen(i,j,k) = CoV*noiselessDataAll(i,metab_j)*randn(1,1) + noiselessDataAll(i,metab_j);
                end

                % Get the average of the noisy data
               baseNoisyData(i,j) = mean(noisyDataGen(i,j,:));

            end
        end

    end

    % For each noisy dataset, now we need to generate the resampled sets 
    noisyDataMatrix = repmat({zeros(size(baseNoisyData))},numResampleIters,1);

    for iteration_k = 1:numResampleIters

        % Reinitialize storage space...
        noisyData = zeros(size(baseNoisyData,1),size(baseNoisyData,2),numReplicates);

        % Generate the noisy measurements
        for j=1:size(baseNoisyData,2)
            for i = 1:size(baseNoisyData,1)

                for k = 1:numReplicates
                    % Add noise to the original measurements
                    noisyData(i,j,k) = CoV*baseNoisyData(i,j)*randn(1,1) + baseNoisyData(i,j);
                end

                % Get the average of the noisy data
                noisyDataMatrix{iteration_k}(i,j) = mean(noisyData(i,j,:));

            end
        end
        
    end
    
    
    save(sprintf('chassResampleNoisy_metab%02d.mat',metab_j),...
        'metabNum',...
        'CoV',...
        'numReplicates',...
        'numRandIters',...
        'numResampleIters',...
        'timeUnit',...
        'concUnit',...
        'colNames',...
        'trueData',...
        'trueDataDeriv',...
        'noiselessData',...
        'noiselessDataDeriv',...
        'baseNoisyData',...
        'noisyDataMatrix',...
        'sampleTime',...
        'smoothTime',...
        'derivSmoothTime',...
        'idxSampleDeriv')

end
