% Made to be run by compareNumTries
% Sorts and plots the cumulative RMSD distribution for each function and
% metabolite. Sort order is determined by the order when run with the max
% value of numTries, such that the RMSD monotonically increases across
% noisy time courses.

if ~exist(plotDir,'dir')
    mkdir(plotDir)
end

fprintf('Plotting Cumulative RMSD Distributions\n');

numTriesList = unique(currentNumTries);
legendStrings = cellstr(reshape(sprintf('numTries = %02d',numTriesList),13,length(numTriesList))');

for plotFunc = unique(currentFunc,'stable')
    
    fprintf('\tFunction: %s\n',plotFunc{1});
    
    for plotMetab = unique(currentMetabNum)

        fprintf('\t\t...Metabolite %02d\n',plotMetab);
    
        idxList = find(all([currentMetabNum==plotMetab; strcmp(currentFunc,plotFunc{1})],1));
        
        [~, idxMaxList] = find(all([currentMetabNum==plotMetab; strcmp(currentFunc,plotFunc{1});currentNumTries==max(currentNumTries(idxList))],1));
        thisSortIdx = sortIdxList{idxMaxList};

        [~, idxMaxMatrix] = max(currentNumTries(idxList));
        [~, idx20Matrix] = find(currentNumTries(idxList) == 25,1,'first');
        rmsdMatrix = [currentRmsdList{idxList}];
        rmsdMatrixSorted = rmsdMatrix(thisSortIdx,idx20Matrix:idxMaxMatrix);
        
        
        % Plot Cumulative RMSD Distributions
        try
            set(0,'DefaultFigureVisible','off')
            h = figure('units','normalized','outerposition',[0 0 1 1]);

            plot(rmsdMatrixSorted)
            legend(legendStrings(idx20Matrix:idxMaxMatrix),'location','EastOutside','fontsize',18)
            title({'Sorted RMSD Distribution',sprintf('%s, Metab %02d: %s',plotFunc{1},plotMetab,currentMetabName{idxList(1)})},'fontsize',18)
            xlabel('Cumulative Iterations','fontsize',18)
            ylabel('Fitting RMSD','fontsize',18)

            fileName = sprintf('%s/cumulativeRMSD_%s_metabolite%02d',plotDir,plotFunc{1},plotMetab);
            print(h,'-dpng','-r600',fileName);
% %             set(h,'Visible','on'); savefig(h,fileName);
            close(h)
            set(0,'DefaultFigureVisible','on')
        catch
            close(h)
            set(0,'DefaultFigureVisible','on')
            fprintf('Error: Cumulative RMSD plot for %s, Metabolite %02d\n',plotFunc{1},plotMetab)
        end

    end
end
        
clear('numTriesList','legendStrings','h','plotFunc','plotMetab','idxList', 'idxMaxList', 'thisSortIdx', 'idxMaxMatrix', 'idx20Matrix', 'rmsdMatrix', 'rmsdMatrixSorted')
            