% Made to be run by compareNumTries
% Plots the RMSD correlation function across metabolilites. Correlations
% are calculated against the RMSD distribution of the max numTries case.

if ~exist(plotDir,'dir')
    mkdir(plotDir)
end

fprintf('Plotting RMSD Correlations\n');

for plotFunc = unique(currentFunc,'stable')
    
    fprintf('\tPlotting Function: %s\n',plotFunc{1});
    
    numTriesList = unique(currentNumTries(find(strcmp(currentFunc,plotFunc{1}))));
    corrMatrix = NaN(length(numTriesList),max(currentMetabNum));


    for plotMetab = unique(currentMetabNum)
        
        fprintf('\t\t...Metabolite %02d\n',plotMetab);
        
        % Which RMSD lists are we looking at for this func/metab?
        idxList = find(all([currentMetabNum==plotMetab; strcmp(currentFunc,plotFunc{1})],1));
        
        % And which of them is for the max numTries value?
        [~, idxMax] = max(currentNumTries(idxList));
        
        % Calculate the actual correlation
        for i = 1:length(idxList)
            corrMatrix(i,plotMetab) = corr(currentRmsdList{idxList(i)},currentRmsdList{idxList(idxMax)});
        end
        
    end
    
    % Now plot for this Function
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);

        plot(numTriesList,corrMatrix(:,unique(currentMetabNum)),'linewidth',2)

        title({'Correlation of RMSD values to max(numTries) case',sprintf('Function: %s',plotFunc{1}),'All Metabolites'},'fontsize',18)
        xlabel('numTries','fontsize',18)
        ylabel('Pearson Correlation','fontsize',18)
        set(gca,'Fontsize',16)
        axis([min(numTriesList) max(numTriesList) 0 1])
        
        legendString = [];
        for i = find(all([currentNumTries==numTriesList(1); strcmp(currentFunc,plotFunc{1})],1));
            legendString{end+1} = sprintf('Metab %02d',currentMetabNum(i));
        end, clear i
        legend(legendString,'Location','EastOutside','fontsize',18)
        
        fileName = sprintf('%s/rmsdCorrelations_%s',plotDir,plotFunc{1});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: RMSD Correlation Plot for %s\n',plotFunc{1})
    end
        
end

clear('legendString','idxList','idxMax','plotMetab','plotFunc','h','filename','corrMatrix','numTriesList');
