% Made to be run by compareSolversDirect
% Ranks each function for each metric for a high level comparison

plotDir = 'directPlots_barRank';
fileNameOut = sprintf('%s/rankMeansTableDirect.txt',plotDir);


if ~exist(plotDir,'dir')
    mkdir(plotDir)
end

fprintf('Ranking functions for each metric\n')

% Get some data about our matrix dimensions
numTotalMetabolites = length(unique(currentMetabNum));
funcList = unique(currentFunc,'stable');
numFunctions = length(unique(currentFunc));


fprintf('\tGenerating Histograms\n')

% Concentration Accuracy
rankMatrix = tiedrank(reshape(cell2mat(directConcAccHd),numIters*numTotalMetabolites,numFunctions)')';
arithmeticRankDirectConcAccHd = mean(rankMatrix,1);
harmonicRankDirectConcAccHd = 1./mean(1./rankMatrix,1);

for i = 1:length(funcList)
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        hist(rankMatrix(:,i))
        ylabel('Frequency','fontsize',18)
        xlabel('Rank','fontsize',18)
        title(sprintf('Rank Distribution\nConcentration Accuracy\nFunction: %s',funcList{i}),'fontsize',18)
        set(gca,'xLim',[1 8])

        fileName = sprintf('%s/rankHist_concAccHd_%s',plotDir,funcList{i});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Rank Histogram plot, Concentration Accuracy, function: %s\n',funcList{i})
    end  
end


% Derivative Accuracy
rankMatrix = tiedrank(reshape(cell2mat(directDerivAccHd),numIters*numTotalMetabolites,numFunctions)')';
arithmeticRankDirectDerivAccHd = mean(rankMatrix,1);
harmonicRankDirectDerivAccHd = 1./mean(1./rankMatrix,1);

for i = 1:length(funcList)
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        hist(rankMatrix(:,i))
        ylabel('Frequency','fontsize',18)
        xlabel('Rank','fontsize',18)
        title(sprintf('Rank Distribution\nDerivative Accuracy\nFunction: %s',funcList{i}),'fontsize',18)
        set(gca,'xLim',[1 8])

        fileName = sprintf('%s/rankHist_derivAccHd_%s',plotDir,funcList{i});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Rank Histogram plot, Derivative Accuracy, function: %s\n',funcList{i})
    end  
end



% Concentration Robustness
rankMatrix = tiedrank(reshape(directConcRobustness,numTotalMetabolites,numFunctions)')';
arithmeticRankDirectConcRobustness = mean(rankMatrix,1);
harmonicRankDirectConcRobustness = 1./mean(1./rankMatrix,1);

for i = 1:length(funcList)
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        hist(rankMatrix(:,i))
        ylabel('Frequency','fontsize',18)
        xlabel('Rank','fontsize',18)
        title(sprintf('Rank Distribution\nConcentration Robustness\nFunction: %s',funcList{i}),'fontsize',18)
        set(gca,'xLim',[1 8])

        fileName = sprintf('%s/rankHist_concRobustness_%s',plotDir,funcList{i});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Rank Histogram plot, Concentration Robustness, function: %s\n',funcList{i})
    end  
end


% Derivative Robustness
rankMatrix = tiedrank(reshape(directDerivRobustness,numTotalMetabolites,numFunctions)')';
arithmeticRankDirectDerivRobustness = mean(rankMatrix,1);
harmonicRankDirectDerivRobustness = 1./mean(1./rankMatrix,1);

for i = 1:length(funcList)
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        hist(rankMatrix(:,i))
        ylabel('Frequency','fontsize',18)
        xlabel('Rank','fontsize',18)
        title(sprintf('Rank Distribution\nDerivative Robustness\nFunction: %s',funcList{i}),'fontsize',18)
        set(gca,'xLim',[1 8])

        fileName = sprintf('%s/rankHist_concRobustness_%s',plotDir,funcList{i});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Rank Histogram plot, Derivative Robustness, function: %s\n',funcList{i})
    end  
end



% Median Concentration Accuracy
rankMatrix = tiedrank(reshape(medianDirectConcAccHd,numTotalMetabolites,numFunctions)')';
arithmeticRankMedianDirectConcAccHd = mean(rankMatrix,1);
harmonicRankMedianDirectConcAccHd = 1./mean(1./rankMatrix,1);

for i = 1:length(funcList)
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        hist(rankMatrix(:,i))
        ylabel('Frequency','fontsize',18)
        xlabel('Rank','fontsize',18)
        title(sprintf('Rank Distribution\nMedian Concentration Accuracy\nFunction: %s',funcList{i}),'fontsize',18)
        set(gca,'xLim',[1 8])

        fileName = sprintf('%s/rankHist_medianConcAccHd_%s',plotDir,funcList{i});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Rank Histogram plot, Concentration Accuracy, function: %s\n',funcList{i})
    end  
end


% Median Derivative Accuracy
rankMatrix = tiedrank(reshape(medianDirectDerivAccHd,numTotalMetabolites,numFunctions)')';
arithmeticRankMedianDirectDerivAccHd = mean(rankMatrix,1);
harmonicRankMedianDirectDerivAccHd = 1./mean(1./rankMatrix,1);

for i = 1:length(funcList)
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        hist(rankMatrix(:,i))
        ylabel('Frequency','fontsize',18)
        xlabel('Rank','fontsize',18)
        title(sprintf('Rank Distribution\nMedian Derivative Accuracy\nFunction: %s',funcList{i}),'fontsize',18)
        set(gca,'xLim',[1 8])

        fileName = sprintf('%s/rankHist_medianDerivativeAccHd_%s',plotDir,funcList{i});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Rank Histogram plot, Derivative Accuracy, function: %s\n',funcList{i})
    end  
end


fprintf('\tGenerating Bar Plots\n')

try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
    subplot(2,1,1)
        title({'Concentration Accuracy'},'fontsize',18)
        bar(arithmeticRankDirectConcAccHd)
        ylabel('Arithmatic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
        
    subplot(2,1,2)
        bar(harmonicRankDirectConcAccHd)
        ylabel('Harmonic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
    
    fileName = sprintf('%s/rankPlots_concAccHd',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar Rank plot, Concentration Accuracy\n')
end

try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
    subplot(2,1,1)
        title({'Derivative Accuracy'},'fontsize',18)
        bar(arithmeticRankDirectDerivAccHd)
        ylabel('Arithmatic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
        
    subplot(2,1,2)
        bar(harmonicRankDirectDerivAccHd)
        ylabel('Harmonic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
    
    fileName = sprintf('%s/rankPlots_derivAccHd',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar Rank plot, Derivative Accuracy\n')
end

try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
    subplot(2,1,1)
        title({'ConcentratioN Robustness'},'fontsize',18)
        bar(arithmeticRankDirectConcRobustness)
        ylabel('Arithmatic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
        
    subplot(2,1,2)
        bar(harmonicRankDirectConcRobustness)
        ylabel('Harmonic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
    
    fileName = sprintf('%s/rankPlots_concRobustness',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar Rank plot, Concentration Robustness\n')
end

try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
    subplot(2,1,1)
        title({'Derivative Robustness'},'fontsize',18)
        bar(arithmeticRankDirectDerivRobustness)
        ylabel('Arithmatic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
        
    subplot(2,1,2)
        bar(harmonicRankDirectDerivRobustness)
        ylabel('Harmonic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
    
    fileName = sprintf('%s/rankPlots_derivRobustness',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar Rank plot, Derivative Robustness\n')
end

try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
    subplot(2,1,1)
        title({'Median Concentration Accuracy'},'fontsize',18)
        bar(arithmeticRankMedianDirectConcAccHd)
        ylabel('Arithmatic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
        
    subplot(2,1,2)
        bar(harmonicRankMedianDirectConcAccHd)
        ylabel('Harmonic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
    
    fileName = sprintf('%s/rankPlots_medianConcAccHd',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar Rank plot, Median Concentration Accuracy\n')
end

try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
    title({'Median Derivative Accuracy'},'fontsize',18)
        
    subplot(2,1,1)
        bar(arithmeticRankMedianDirectDerivAccHd)
        ylabel('Arithmatic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
        
    subplot(2,1,2)
        bar(harmonicRankMedianDirectDerivAccHd)
        ylabel('Harmonic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
    
    fileName = sprintf('%s/rankPlots_medianDerivAccHd',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar Rank plot, Median Derivative Accuracy\n')
end


fprintf('\tGenerating Tabulated Results\n')

fileOut = fopen(fileNameOut,'w');

    fprintf(fileOut,'\n');
    fprintf(fileOut,'\tMetric');
    fprintf(fileOut,'\t%s',funcList{:});
    fprintf(fileOut,'\n');
    

    fprintf(fileOut,'\tArithmetic Mean: Concentration Accuracy');
    fprintf(fileOut,'\t%.5f',arithmeticRankDirectConcAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tArithmetic Mean: Derivative Accuracy');
    fprintf(fileOut,'\t%.5f',arithmeticRankDirectDerivAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tArithmetic Mean: Concentration Robustness');
    fprintf(fileOut,'\t%.5f',arithmeticRankDirectConcRobustness);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tArithmetic Mean: Derivative Robustness');
    fprintf(fileOut,'\t%.5f',arithmeticRankDirectDerivRobustness);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tArithmetic Mean: Median Concentration Accuracy');
    fprintf(fileOut,'\t%.5f',arithmeticRankMedianDirectConcAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tArithmetic Mean: Median Derivative Accuracy');
    fprintf(fileOut,'\t%.5f',arithmeticRankMedianDirectDerivAccHd);
    fprintf(fileOut,'\n');


    fprintf(fileOut,'\n');
    fprintf(fileOut,'\n');


    fprintf(fileOut,'\tHarmonic Mean: Concentration Accuracy');
    fprintf(fileOut,'\t%.5f',harmonicRankDirectConcAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tHarmonic Mean: Derivative Accuracy');
    fprintf(fileOut,'\t%.5f',harmonicRankDirectDerivAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tHarmonic Mean: Concentration Robustness');
    fprintf(fileOut,'\t%.5f',harmonicRankDirectConcRobustness);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tHarmonic Mean: Derivative Robustness');
    fprintf(fileOut,'\t%.5f',harmonicRankDirectDerivRobustness);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tHarmonic Mean: Median Concentration Accuracy');
    fprintf(fileOut,'\t%.5f',harmonicRankMedianDirectConcAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tHarmonic Mean: Median Derivative Accuracy');
    fprintf(fileOut,'\t%.5f',harmonicRankMedianDirectDerivAccHd);
    fprintf(fileOut,'\n');

fclose(fileOut);