% Made to be run by compareSolversResample
% Ranks each function for each metric for a high level comparison

plotDir = 'resamplePlots_barRank';
fileNameOut = sprintf('%s/rankMeansTableResample.txt',plotDir);


if ~exist(plotDir,'dir')
    mkdir(plotDir)
end

fprintf('Ranking functions for each metric\n')

% Get some data about our matrix dimensions
numTotalMetabolites = length(unique(currentMetabNum));
funcList = unique(currentFunc,'stable');
numFunctions = length(unique(currentFunc));


fprintf('\tGenerating Histograms\n')


% Concentration Accuracy
rankMatrix = tiedrank(reshape(cell2mat(medianResampleConcAccHd),numRandIters*numTotalMetabolites,numFunctions)')';
arithmeticRankResampleConcAccHd = mean(rankMatrix,1);
harmonicRankResampleConcAccHd = 1./mean(1./rankMatrix,1);

for i = 1:length(funcList)
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        hist(rankMatrix(:,i))
        ylabel('Frequency','fontsize',18)
        xlabel('Rank','fontsize',18)
        title(sprintf('Rank Distribution\nConcentration Accuracy\nFunction: %s',funcList{i}),'fontsize',18)
        set(gca,'xLim',[1 8])

        fileName = sprintf('%s/rankHist_concAccHd_%s',plotDir,funcList{i});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Rank Histogram plot, Concentration Accuracy, function: %s\n',funcList{i})
    end  
end


% Derivative Accuracy
rankMatrix = tiedrank(reshape(cell2mat(medianResampleDerivAccHd),numRandIters*numTotalMetabolites,numFunctions)')';
arithmeticRankResampleDerivAccHd = mean(rankMatrix,1);
harmonicRankResampleDerivAccHd = 1./mean(1./rankMatrix,1);

for i = 1:length(funcList)
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        hist(rankMatrix(:,i))
        ylabel('Frequency','fontsize',18)
        xlabel('Rank','fontsize',18)
        title(sprintf('Rank Distribution\nDerivative Accuracy\nFunction: %s',funcList{i}),'fontsize',18)
        set(gca,'xLim',[1 8])

        fileName = sprintf('%s/rankHist_derivAccHd_%s',plotDir,funcList{i});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Rank Histogram plot, Derivative Accuracy, function: %s\n',funcList{i})
    end  
end



% Concentration Robustness
rankMatrix = tiedrank(reshape(medianResampleConcRobustness,numTotalMetabolites,numFunctions)')';
arithmeticRankResampleConcRobustness = mean(rankMatrix,1);
harmonicRankResampleConcRobustness = 1./mean(1./rankMatrix,1);

for i = 1:length(funcList)
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        hist(rankMatrix(:,i))
        ylabel('Frequency','fontsize',18)
        xlabel('Rank','fontsize',18)
        title(sprintf('Rank Distribution\nConcentration Robustness\nFunction: %s',funcList{i}),'fontsize',18)
        set(gca,'xLim',[1 8])

        fileName = sprintf('%s/rankHist_concRobustness_%s',plotDir,funcList{i});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Rank Histogram plot, Concentration Robustness, function: %s\n',funcList{i})
    end  
end


% Derivative Robustness
rankMatrix = tiedrank(reshape(medianResampleDerivRobustness,numTotalMetabolites,numFunctions)')';
arithmeticRankResampleDerivRobustness = mean(rankMatrix,1);
harmonicRankResampleDerivRobustness = 1./mean(1./rankMatrix,1);

for i = 1:length(funcList)
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        hist(rankMatrix(:,i))
        ylabel('Frequency','fontsize',18)
        xlabel('Rank','fontsize',18)
        title(sprintf('Rank Distribution\nDerivative Robustness\nFunction: %s',funcList{i}),'fontsize',18)
        set(gca,'xLim',[1 8])

        fileName = sprintf('%s/rankHist_concRobustness_%s',plotDir,funcList{i});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Rank Histogram plot, Derivative Robustness, function: %s\n',funcList{i})
    end  
end


% Median Concentration Accuracy
rankMatrix = tiedrank(reshape(medianOfMedianConcAccHd,numTotalMetabolites,numFunctions)')';
arithmeticRankMedianResampleConcAccHd = mean(rankMatrix,1);
harmonicRankMedianResampleConcAccHd = 1./mean(1./rankMatrix,1);

for i = 1:length(funcList)
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        hist(rankMatrix(:,i))
        ylabel('Frequency','fontsize',18)
        xlabel('Rank','fontsize',18)
        title(sprintf('Rank Distribution\nMedian Concentration Accuracy\nFunction: %s',funcList{i}),'fontsize',18)
        set(gca,'xLim',[1 8])

        fileName = sprintf('%s/rankHist_medianConcAccHd_%s',plotDir,funcList{i});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Rank Histogram plot, Concentration Accuracy, function: %s\n',funcList{i})
    end  
end


% Median Derivative Accuracy
rankMatrix = tiedrank(reshape(medianOfMedianDerivAccHd,numTotalMetabolites,numFunctions)')';
arithmeticRankMedianResampleDerivAccHd = mean(rankMatrix,1);
harmonicRankMedianResampleDerivAccHd = 1./mean(1./rankMatrix,1);

for i = 1:length(funcList)
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        hist(rankMatrix(:,i))
        ylabel('Frequency','fontsize',18)
        xlabel('Rank','fontsize',18)
        title(sprintf('Rank Distribution\nMedian Derivative Accuracy\nFunction: %s',funcList{i}),'fontsize',18)
        set(gca,'xLim',[1 8])

        fileName = sprintf('%s/rankHist_medianDerivativeAccHd_%s',plotDir,funcList{i});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Rank Histogram plot, Derivative Accuracy, function: %s\n',funcList{i})
    end  
end


fprintf('\tGenerating Bar Plots\n')

try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
    subplot(2,1,1)
        title({'Concentration Accuracy'},'fontsize',18)
        bar(arithmeticRankResampleConcAccHd)
        ylabel('Arithmatic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
        
    subplot(2,1,2)
        bar(harmonicRankResampleConcAccHd)
        ylabel('Harmonic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
    
    fileName = sprintf('%s/rankPlots_concAccHd',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar Rank plot, Concentration Accuracy\n')
end

try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
    subplot(2,1,1)
        title({'Derivative Accuracy'},'fontsize',18)
        bar(arithmeticRankResampleDerivAccHd)
        ylabel('Arithmatic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
        
    subplot(2,1,2)
        bar(harmonicRankResampleDerivAccHd)
        ylabel('Harmonic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
    
    fileName = sprintf('%s/rankPlots_derivAccHd',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar Rank plot, Derivative Accuracy\n')
end

try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
    subplot(2,1,1)
        title({'ConcentratioN Robustness'},'fontsize',18)
        bar(arithmeticRankResampleConcRobustness)
        ylabel('Arithmatic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
        
    subplot(2,1,2)
        bar(harmonicRankResampleConcRobustness)
        ylabel('Harmonic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
    
    fileName = sprintf('%s/rankPlots_concRobustness',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar Rank plot, Concentration Robustness\n')
end

try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
    subplot(2,1,1)
        title({'Derivative Robustness'},'fontsize',18)
        bar(arithmeticRankResampleDerivRobustness)
        ylabel('Arithmatic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
        
    subplot(2,1,2)
        bar(harmonicRankResampleDerivRobustness)
        ylabel('Harmonic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
    
    fileName = sprintf('%s/rankPlots_derivRobustness',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar Rank plot, Derivative Robustness\n')
end

try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
    subplot(2,1,1)
        title({'Median Concentration Accuracy'},'fontsize',18)
        bar(arithmeticRankMedianResampleConcAccHd)
        ylabel('Arithmatic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
        
    subplot(2,1,2)
        bar(harmonicRankMedianResampleConcAccHd)
        ylabel('Harmonic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
    
    fileName = sprintf('%s/rankPlots_medianConcAccHd',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar Rank plot, Median Concentration Accuracy\n')
end

try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
    title({'Median Derivative Accuracy'},'fontsize',18)
        
    subplot(2,1,1)
        bar(arithmeticRankMedianResampleDerivAccHd)
        ylabel('Arithmatic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
        
    subplot(2,1,2)
        bar(harmonicRankMedianResampleDerivAccHd)
        ylabel('Harmonic Mean of Rank','fontsize',18)
        set(gca,'XTickLabel',funcList,'fontsize',18)
    
    fileName = sprintf('%s/rankPlots_medianDerivAccHd',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar Rank plot, Median Derivative Accuracy\n')
end


fprintf('\tGenerating Tabulated Resuls\n')

fileOut = fopen(fileNameOut,'w');

    fprintf(fileOut,'\n');
    fprintf(fileOut,'\tMetric');
    fprintf(fileOut,'\t%s',funcList{:});
    fprintf(fileOut,'\n');

    
    fprintf(fileOut,'\tArithmetic Mean: Concentration Accuracy');
    fprintf(fileOut,'\t%.5f',arithmeticRankResampleConcAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tArithmetic Mean: Derivative Accuracy');
    fprintf(fileOut,'\t%.5f',arithmeticRankResampleDerivAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tArithmetic Mean: Concentration Robustness');
    fprintf(fileOut,'\t%.5f',arithmeticRankResampleConcRobustness);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tArithmetic Mean: Derivative Robustness');
    fprintf(fileOut,'\t%.5f',arithmeticRankResampleDerivRobustness);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tArithmetic Mean: Median Concentration Accuracy');
    fprintf(fileOut,'\t%.5f',arithmeticRankMedianResampleConcAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tArithmetic Mean: Median Derivative Accuracy');
    fprintf(fileOut,'\t%.5f',arithmeticRankMedianResampleDerivAccHd);
    fprintf(fileOut,'\n');


    fprintf(fileOut,'\n');
    fprintf(fileOut,'\n');


    fprintf(fileOut,'\tHarmonic Mean: Concentration Accuracy');
    fprintf(fileOut,'\t%.5f',harmonicRankResampleConcAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tHarmonic Mean: Derivative Accuracy');
    fprintf(fileOut,'\t%.5f',harmonicRankResampleDerivAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tHarmonic Mean: Concentration Robustness');
    fprintf(fileOut,'\t%.5f',harmonicRankResampleConcRobustness);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tHarmonic Mean: Derivative Robustness');
    fprintf(fileOut,'\t%.5f',harmonicRankResampleDerivRobustness);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tHarmonic Mean: Median Concentration Accuracy');
    fprintf(fileOut,'\t%.5f',harmonicRankMedianResampleConcAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tHarmonic Mean: Median Derivative Accuracy');
    fprintf(fileOut,'\t%.5f',harmonicRankMedianResampleDerivAccHd);
    fprintf(fileOut,'\n');

fclose(fileOut);
