% Made to be run by compareSolversResample
% Ranks each function for each metric for a high level comparison
% This script in particular compares Direct Fit AND Resampling together

plotDir = 'resamplePlots_barRank';
fileNameOut = sprintf('%s/rankMeansTableResampleVsDirect.txt',plotDir);


if ~exist(plotDir,'dir')
    mkdir(plotDir)
end

fprintf('Ranking Resampling vs Direct Fit methods\n')

% Get some data about our matrix dimensions
numTotalMetabolites = length(unique(currentMetabNum));
funcList = unique(currentFunc,'stable');
numFunctions = length(unique(currentFunc));



% Concentration Accuracy
rankMatrix = tiedrank([reshape(cell2mat(medianResampleConcAccHd),numRandIters*numTotalMetabolites,numFunctions)'; reshape(cell2mat(directConcAccHd),numRandIters*numTotalMetabolites,numFunctions)'])';
arithmeticRankConcAccHd = mean(rankMatrix,1);
harmonicRankConcAccHd = 1./mean(1./rankMatrix,1);

% Derivative Accuracy
rankMatrix = tiedrank([reshape(cell2mat(medianResampleDerivAccHd),numRandIters*numTotalMetabolites,numFunctions)'; reshape(cell2mat(directDerivAccHd),numRandIters*numTotalMetabolites,numFunctions)'])';
arithmeticRankDerivAccHd = mean(rankMatrix,1);
harmonicRankDerivAccHd = 1./mean(1./rankMatrix,1);


% Concentration Robustness
rankMatrix = tiedrank([reshape(medianResampleConcRobustness,numTotalMetabolites,numFunctions)'; reshape(directConcRobustness,numTotalMetabolites,numFunctions)'])';
arithmeticRankConcRobustness = mean(rankMatrix,1);
harmonicRankConcRobustness = 1./mean(1./rankMatrix,1);

% Derivative Robustness
rankMatrix = tiedrank([reshape(medianResampleDerivRobustness,numTotalMetabolites,numFunctions)'; reshape(directDerivRobustness,numTotalMetabolites,numFunctions)'])';
arithmeticRankDerivRobustness = mean(rankMatrix,1);
harmonicRankDerivRobustness = 1./mean(1./rankMatrix,1);


% Median Concentration Accuracy
rankMatrix = tiedrank([reshape(medianOfMedianConcAccHd,numTotalMetabolites,numFunctions)'; reshape(medianDirectConcAccHd,numTotalMetabolites,numFunctions)'])';
arithmeticRankMedianConcAccHd = mean(rankMatrix,1);
harmonicRankMedianConcAccHd = 1./mean(1./rankMatrix,1);

% Median Derivative Accuracy
rankMatrix = tiedrank([reshape(medianOfMedianDerivAccHd,numTotalMetabolites,numFunctions)'; reshape(medianDirectDerivAccHd,numTotalMetabolites,numFunctions)'])';
arithmeticRankMedianDerivAccHd = mean(rankMatrix,1);
harmonicRankMedianDerivAccHd = 1./mean(1./rankMatrix,1);



fileOut = fopen(fileNameOut,'w');

    fprintf(fileOut,'\n');
    fprintf(fileOut,'\tMetric');
    fprintf(fileOut,'\tRsp %s',funcList{:});
    fprintf(fileOut,'\tDir %s',funcList{:});
    fprintf(fileOut,'\n');


    fprintf(fileOut,'\tArithmetic Mean: Concentration Accuracy');
    fprintf(fileOut,'\t%.5f',arithmeticRankConcAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tArithmetic Mean: Derivative Accuracy');
    fprintf(fileOut,'\t%.5f',arithmeticRankDerivAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tArithmetic Mean: Concentration Robustness');
    fprintf(fileOut,'\t%.5f',arithmeticRankConcRobustness);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tArithmetic Mean: Derivative Robustness');
    fprintf(fileOut,'\t%.5f',arithmeticRankDerivRobustness);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tArithmetic Mean: Median Concentration Accuracy');
    fprintf(fileOut,'\t%.5f',arithmeticRankMedianConcAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tArithmetic Mean: Median Derivative Accuracy');
    fprintf(fileOut,'\t%.5f',arithmeticRankMedianDerivAccHd);
    fprintf(fileOut,'\n');


    fprintf(fileOut,'\n');
    fprintf(fileOut,'\n');

    
    fprintf(fileOut,'\tHarmonic Mean: Concentration Accuracy');
    fprintf(fileOut,'\t%.5f',harmonicRankConcAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tHarmonic Mean: Derivative Accuracy');
    fprintf(fileOut,'\t%.5f',harmonicRankDerivAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tHarmonic Mean: Concentration Robustness');
    fprintf(fileOut,'\t%.5f',harmonicRankConcRobustness);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tHarmonic Mean: Derivative Robustness');
    fprintf(fileOut,'\t%.5f',harmonicRankDerivRobustness);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tHarmonic Mean: Median Concentration Accuracy');
    fprintf(fileOut,'\t%.5f',harmonicRankMedianConcAccHd);
    fprintf(fileOut,'\n');

    fprintf(fileOut,'\tHarmonic Mean: Median Derivative Accuracy');
    fprintf(fileOut,'\t%.5f',harmonicRankMedianDerivAccHd);
    fprintf(fileOut,'\n');

fclose(fileOut);
