% Made to be run by compareSolversResample
% Generates bar plots comparing metrics across functions
    
plotDir = 'resamplePlots_bar';


if ~exist(plotDir,'dir')
    mkdir(plotDir)
end

% Get info about what we're plotting
% % numSpacerMetabs = min(currentMetabNum)-1;
numActualMetabs = length(unique(currentMetabNum));
actualMetabList = unique(currentMetabNum);
numFuncs = length(unique(currentFunc));
barFuncList = unique(currentFunc,'stable');

fprintf('Generating Bar Plots:\n\tOverall Average Performance\n')

% meanConcAccHd
try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
% %     bar(-log10([zeros(numSpacerMetabs,numFuncs); reshape(medianOfMedianConcAccHd,numActualMetabs,numFuncs)]))
    plot(actualMetabList,log10(reshape(medianOfMedianConcAccHd,numActualMetabs,numFuncs)),'linewidth',1,'linestyle','--','marker','s')
    title({'Resample Method','Concentration Accuracy'},'fontsize',18)
    xlabel('Metabolite','fontsize',18)
    ylabel('log_1_0(Error)','fontsize',18)
    xlim([min(actualMetabList),max(actualMetabList)])
    legend(barFuncList,'Location','EastOutside','fontsize',18)

    fileName = sprintf('%s/bar_noVariance_concAccHd_allMetab',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar plot for all metabolites: Concentration Accuracy\n')
end

% meanDerivAccHd
try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
% %     bar(-log10([zeros(numSpacerMetabs,numFuncs); reshape(medianOfMedianDerivAccHd,numActualMetabs,numFuncs)]))
    plot(actualMetabList,log10(reshape(medianOfMedianDerivAccHd,numActualMetabs,numFuncs)),'linewidth',1,'linestyle','--','marker','s')
    title({'Resample Method','Derivative Accuracy'},'fontsize',18)
    xlabel('Metabolite','fontsize',18)
    ylabel('log_1_0(Error)','fontsize',18)
    xlim([min(actualMetabList),max(actualMetabList)])
    legend(barFuncList,'Location','EastOutside','fontsize',18)

    fileName = sprintf('%s/bar_noVariance_derivAccHd_allMetab',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar plot for all metabolites: Derivative Accuracy\n')
end

% meanConcRobustness
try
        set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
% %     bar(-log10([zeros(numSpacerMetabs,numFuncs); reshape(medianResampleConcRobustness,numActualMetabs,numFuncs)]))
    plot(actualMetabList,log10(reshape(medianResampleConcRobustness,numActualMetabs,numFuncs)),'linewidth',1,'linestyle','--','marker','s')
    title({'Resample Method','Concentration Robustness'},'fontsize',18)
    xlabel('Metabolite','fontsize',18)
    ylabel('log_1_0(Variability)','fontsize',18)
    xlim([min(actualMetabList),max(actualMetabList)])
    legend(barFuncList,'Location','EastOutside','fontsize',18)

    fileName = sprintf('%s/bar_concRobustness_allMetab',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar plot for all metabolites: Concentration Robustness\n')
end

% meanDerivRobustness
try
        set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
% %     bar(-log10([zeros(numSpacerMetabs,numFuncs); reshape(medianResampleDerivRobustness,numActualMetabs,numFuncs)]))
    plot(actualMetabList,log10(reshape(medianResampleDerivRobustness,numActualMetabs,numFuncs)),'linewidth',1,'linestyle','--','marker','s')
    title({'Resample Method','Derivative Robustness'},'fontsize',18)
    xlabel('Metabolite','fontsize',18)
    ylabel('log_1_0(Variability)','fontsize',18)
    xlim([min(actualMetabList),max(actualMetabList)])
    legend(barFuncList,'Location','EastOutside','fontsize',18)

    fileName = sprintf('%s/bar_derivRobustness_allMetab',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar plot for all metabolites: Derivative Robustness\n')
end



for metab_k = unique(currentMetabNum)
    
    fprintf('\tMetabolite %02d...\n',metab_k)

    idxMetab = find(currentMetabNum == metab_k);

    % concAccHd
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        barweb(medianOfMedianConcAccHd(idxMetab),medianResampleConcDispersion(idxMetab));
        title({'Resample Method','Concentration Accuracy'},'fontsize',18)
        xlabel(sprintf('Metabolite %02d: %s',metab_k,currentMetabName{idxMetab(1)}),'fontsize',18)
        set(gca,'fontsize',18)
        set(gca,'xticklabel',[])
        ylabel('Error','fontsize',18)
        legend(barFuncList,'Location','EastOutside','fontsize',18)

        fileName = sprintf('%s/bar_concAccHd_metab%02d',plotDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Bar plot for metabolite %02d: Concentration Accuracy\n',metab_k)
    end

    % derivAccHd
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        barweb(medianOfMedianDerivAccHd(idxMetab),medianResampleDerivDispersion(idxMetab)); 
        title({'Resample Method','Derivative Accuracy'},'fontsize',18)
        xlabel(sprintf('Metabolite %02d: %s',metab_k,currentMetabName{idxMetab(1)}),'fontsize',18)
        set(gca,'fontsize',18)
        set(gca,'xticklabel',[])
        ylabel('Error','fontsize',18)
        legend(barFuncList,'Location','EastOutside','fontsize',18)

        fileName = sprintf('%s/bar_derivAccHd_metab%02d',plotDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Bar plot for metabolite %02d: Derivative Accuracy\n',metab_k)
    end

    % concAccHd
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        barweb(medianOfMedianConcAccHd(idxMetab),zeros(size(medianResampleConcDispersion(idxMetab))));
        title({'Resample Method','Concentration Accuracy'},'fontsize',18)
        xlabel(sprintf('Metabolite %02d: %s',metab_k,currentMetabName{idxMetab(1)}),'fontsize',18)
        set(gca,'fontsize',18)
        set(gca,'xticklabel',[])
        ylabel('Error','fontsize',18)
        legend(barFuncList,'Location','EastOutside','fontsize',18)

        fileName = sprintf('%s/bar_noVariance_concAccHd_metab%02d',plotDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Bar plot for metabolite %02d: Concentration Accuracy, no variance\n',metab_k)
    end

    % derivAccHd
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        barweb(medianOfMedianDerivAccHd(idxMetab),zeros(size(medianResampleDerivDispersion(idxMetab)))); 
        title({'Resample Method','Derivative Accuracy'},'fontsize',18)
        xlabel(sprintf('Metabolite %02d: %s',metab_k,currentMetabName{idxMetab(1)}),'fontsize',18)
        set(gca,'fontsize',18)
        set(gca,'xticklabel',[])
        ylabel('Error','fontsize',18)
        legend(barFuncList,'Location','EastOutside','fontsize',18)

        fileName = sprintf('%s/bar_noVariance_derivAccHd_metab%02d',plotDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Bar plot for metabolite %02d: Derivative Accuracy, no variance\n',metab_k)
    end


    % concRobustness
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        barweb(medianResampleConcRobustness(idxMetab),zeros(size(medianResampleConcRobustness(idxMetab)))); 
        title({'Resample Method','Concentration Robustness'},'fontsize',18)
        xlabel(sprintf('Metabolite %02d: %s',metab_k,currentMetabName{idxMetab(1)}),'fontsize',18)
        set(gca,'fontsize',18)
        set(gca,'xticklabel',[])
        ylabel('Variability','fontsize',18)
        legend(barFuncList,'Location','EastOutside','fontsize',18)

        fileName = sprintf('%s/bar_concRobustness_metab%02d',plotDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Bar plot for metabolite %02d: Concentration Robustness\n',metab_k)
    end

    % derivRobustness
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        barweb(medianResampleDerivRobustness(idxMetab),zeros(size(medianResampleDerivRobustness(idxMetab)))); 
        title({'Resample Method','Derivative Robustness'},'fontsize',18)
        xlabel(sprintf('Metabolite %02d: %s',metab_k,currentMetabName{idxMetab(1)}),'fontsize',18)
        set(gca,'fontsize',18)
        set(gca,'xticklabel',[])
        ylabel('Variability','fontsize',18)
        legend(barFuncList,'Location','EastOutside','fontsize',18)

        fileName = sprintf('%s/bar_derivRobustness_metab%02d',plotDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Bar plot for metabolite %02d: Derivative Robustness\n',metab_k)
    end

end

clear('numActualMetabs','actualMetabList','numFuncs','barFuncList');
