% Made to be run by compareSolversDirect
% Generates scatterplots comparing Functions for each metric, metabolite

plotDir = 'directPlots_scatter_compareFunctions';


if ~exist(plotDir,'dir')
    mkdir(plotDir)
end

% Which function are we comparing against the others?
masterFunc = 'impls';

% And get a list of everything else we have data compiled for
compareFuncList =  unique(currentFunc(~strcmp(currentFunc,masterFunc)),'stable');

fprintf('Generating Scatterplots\n');


% Let's compare each of the functions against the masterFunc
for compareFunc = compareFuncList

    fprintf('\t%s vs %s\n',compareFunc{1},masterFunc);

    % Which parts of my compilation list do I care about atm?
    idx1 = find(strcmp(currentFunc,masterFunc));
    idx2 = find(strcmp(currentFunc,compareFunc{1}));

    % concAccHd
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);

        maxVal = 1.1*max([medianDirectConcAccHd(idx1), medianDirectConcAccHd(idx2)]);
        minVal = 0.9*min([medianDirectConcAccHd(idx1), medianDirectConcAccHd(idx2)]);
        if minVal < 0.6*maxVal
            minVal = 0;
        end

        plot(medianDirectConcAccHd(idx1),medianDirectConcAccHd(idx2),'r*',...
             median(medianDirectConcAccHd(idx1)),median(medianDirectConcAccHd(idx2)),'g*',...
             [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
        title({'Concentration Accuracy','Direct Method','All Metabolites',sprintf('Pearson: %.4f',corr(medianDirectConcAccHd(idx1)',medianDirectConcAccHd(idx2)'))},'fontsize',18)
        xlabel(sprintf('%s',masterFunc),'fontsize',18)
        ylabel(sprintf('%s',compareFunc{1}),'fontsize',18)
        legend({'Metabolite Averages','Overall Average'},'Location','EastOutside','fontsize',18)
        axis square
        axis([minVal, maxVal, minVal, maxVal])

        fileName = sprintf('%s/scatter_concAccHd_%s_v_%s',plotDir,compareFunc{1},masterFunc);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Scatter plot for %s vs %s, all metabolites: Concentration Accuracy\n',compareFunc{1},masterFunc)
    end

    % derivAccHd
    try
% %         set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);

        maxVal = 1.1*max([medianDirectDerivAccHd(idx1), medianDirectDerivAccHd(idx2)]);
        minVal = 0.9*min([medianDirectDerivAccHd(idx1), medianDirectDerivAccHd(idx2)]);
        if minVal < 0.6*maxVal
            minVal = 0;
        end

        plot(medianDirectDerivAccHd(idx1),medianDirectDerivAccHd(idx2),'r*',...
             median(medianDirectDerivAccHd(idx1)),median(medianDirectDerivAccHd(idx2)),'g*',...
             [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
        title({'Derivative Accuracy','Direct Method','All Metabolites',sprintf('Pearson: %.4f',corr(medianDirectDerivAccHd(idx1)',medianDirectDerivAccHd(idx2)'))},'fontsize',18)
        xlabel(sprintf('%s',masterFunc),'fontsize',18)
        ylabel(sprintf('%s',compareFunc{1}),'fontsize',18)
        legend({'Metabolite Averages','Overall Average'},'Location','EastOutside','fontsize',18)
        axis square
        axis([minVal, maxVal, minVal, maxVal])

        fileName = sprintf('%s/scatter_derivAccHd_%s_v_%s',plotDir,compareFunc{1},masterFunc);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Scatter plot for %s vs %s, all metabolites: Derivative Accuracy\n',compareFunc{1},masterFunc)
    end

    % concRobustness
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);

        maxVal = 1.1*max([directConcRobustness(idx1), directConcRobustness(idx2)]);
        minVal = 0.9*min([directConcRobustness(idx1), directConcRobustness(idx2)]);
        if minVal < 0.6*maxVal
            minVal = 0;
        end

        plot(directConcRobustness(idx1),directConcRobustness(idx2),'r*',...
             median(directConcRobustness(idx1)),median(directConcRobustness(idx2)),'g*',...
             [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
        title({'Concentration Robustness','Direct Method','All Metabolites',sprintf('Pearson: %.4f',corr(directConcRobustness(idx1)',directConcRobustness(idx2)'))},'fontsize',18)
        xlabel(sprintf('%s',masterFunc),'fontsize',18)
        ylabel(sprintf('%s',compareFunc{1}),'fontsize',18)
        legend({'Metabolite Averages','Overall Average'},'Location','EastOutside','fontsize',18)
        axis square
        axis([minVal, maxVal, minVal, maxVal])

        fileName = sprintf('%s/scatter_concRobustness_%s_v_%s',plotDir,compareFunc{1},masterFunc);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Scatter plot for %s vs %s, all metabolites: Concentration Robustness\n',compareFunc{1},masterFunc)
    end

    % derivRobustness
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);

        maxVal = 1.1*max([directDerivRobustness(idx1), directDerivRobustness(idx2)]);
        minVal = 0.9*min([directDerivRobustness(idx1), directDerivRobustness(idx2)]);
        if minVal < 0.6*maxVal
            minVal = 0;
        end

        plot(directDerivRobustness(idx1),directDerivRobustness(idx2),'r*',...
             median(directDerivRobustness(idx1)),median(directDerivRobustness(idx2)),'g*',...
             [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
        title({'Derivative Robusntess','Direct Method','All Metabolites',sprintf('Pearson: %.4f',corr(directDerivRobustness(idx1)',directDerivRobustness(idx2)'))},'fontsize',18)
        xlabel(sprintf('%s',masterFunc),'fontsize',18)
        ylabel(sprintf('%s',compareFunc{1}),'fontsize',18)
        legend({'Metabolite Averages','Overall Average'},'Location','EastOutside','fontsize',18)
        axis square
        axis([minVal, maxVal, minVal, maxVal])

        fileName = sprintf('%s/scatter_derivRobustness_%s_v_%s',plotDir,compareFunc{1},masterFunc);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Scatter plot for %s vs %s, all metabolites: Derivative Robustness\n',compareFunc{1},masterFunc)
    end


    % Now, let's break it down for each metabolite
    for metab_k = unique(currentMetabNum)

        fprintf('\t\t...Metabolite %d\n',metab_k);

        % Which parts of my compilation list do I care about atm?
        idx1 = find(all([strcmp(currentFunc,masterFunc);currentMetabNum==metab_k],1));
        idx2 = find(all([strcmp(currentFunc,compareFunc{1});currentMetabNum==metab_k],1));

        if length(idx1) > 1 || length(idx2)>1
            fprintf('\t\tWarning! Repeat datasets!\n')
        end

        % concAccHd
        try
            set(0,'DefaultFigureVisible','off')
            h = figure('units','normalized','outerposition',[0 0 1 1]);

            maxVal = 1.1*max([directConcAccHd{idx1}, directConcAccHd{idx2}]);
            minVal = 0.9*min([directConcAccHd{idx1}, directConcAccHd{idx2}]);
            if minVal < 0.6*maxVal
                minVal = 0;
            end

            plot(directConcAccHd{idx1},directConcAccHd{idx2},'r*',...
                 median(directConcAccHd{idx1}),median(directConcAccHd{idx2}),'g*',...
                 [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
            title({'Concentration Accuracy','Direct Method',sprintf('Metab %02d: %s',metab_k,currentMetabName{idx1(1)}),sprintf('Pearson: %.4f',corr(directConcAccHd{idx1}',directConcAccHd{idx2}'))},'fontsize',18)
            xlabel(sprintf('%s',masterFunc),'fontsize',18)
            ylabel(sprintf('%s',compareFunc{1}),'fontsize',18)
            legend({'Noisy Datasets','Metabolite Average'},'Location','EastOutside','fontsize',18)
            axis square
            axis([minVal, maxVal, minVal, maxVal])

            fileName = sprintf('%s/scatter_concAccHd_%s_v_%s_metab%02d',plotDir,compareFunc{1},masterFunc,metab_k);
            print(h,'-dpng','-r600',fileName);
            close(h)
            set(0,'DefaultFigureVisible','on')
        catch
            close(h)
            set(0,'DefaultFigureVisible','on')
            fprintf('Error: Scatter plot for %s vs %s, metabolite %02dConcentration Accuracy\n',compareFunc{1},masterFunc,metab_k)
        end

        % derivAccHd
        try
            set(0,'DefaultFigureVisible','off')
            h = figure('units','normalized','outerposition',[0 0 1 1]);

            maxVal = 1.1*max([directDerivAccHd{idx1}, directDerivAccHd{idx2}]);
            minVal = 0.9*min([directDerivAccHd{idx1}, directDerivAccHd{idx2}]);
            if minVal < 0.6*maxVal
                minVal = 0;
            end

            plot(directDerivAccHd{idx1},directDerivAccHd{idx2},'r*',...
                 median(directDerivAccHd{idx1}),median(directDerivAccHd{idx2}),'g*',...
                 [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
            title({'Derivative Accuracy','Direct Method',sprintf('Metab %02d: %s',metab_k,currentMetabName{idx1(1)}),sprintf('Pearson: %.4f',corr(directDerivAccHd{idx1}',directDerivAccHd{idx2}'))},'fontsize',18)
            xlabel(sprintf('%s',masterFunc),'fontsize',18)
            ylabel(sprintf('%s',compareFunc{1}),'fontsize',18)
            legend({'Noisy Datasets','Metabolite Average'},'Location','EastOutside','fontsize',18)
            axis square
            axis([minVal, maxVal, minVal, maxVal])

            fileName = sprintf('%s/scatter_derivAccHd_%s_v_%s_metab%02d',plotDir,compareFunc{1},masterFunc,metab_k);
            print(h,'-dpng','-r600',fileName);
            close(h)
            set(0,'DefaultFigureVisible','on')
        catch
            close(h)
            set(0,'DefaultFigureVisible','on')
            fprintf('Error: Scatter plot for %s vs %s, metabolite %02dDerivative Accuracy\n',compareFunc{1},masterFunc,metab_k)
        end
    end

end

clear('numMetabs','numFuncs','barFuncList');
