% Made to be run by compareSolversResample
% Generates scatterplots comparing Functions for each metric, metabolite

plotDir = 'resamplePlots_scatter_compareFunctions';


if ~exist(plotDir,'dir')
    mkdir(plotDir)
end

% Which function are we comparing against the others?
masterFunc = 'impls';

% And get a list of everything else we have data compiled for
compareFuncList =  unique(currentFunc(~strcmp(currentFunc,masterFunc)),'stable');
    
fprintf('Generating Scatterplots\n');


% Let's compare each of the functions against the masterFunc
for compareFunc = compareFuncList
    
    fprintf('\t%s vs %s\n',compareFunc{1},masterFunc);

    % Which parts of my compilation list do I care about atm?
    idx1 = find(strcmp(currentFunc,masterFunc));
    idx2 = find(strcmp(currentFunc,compareFunc{1}));

    % concAccHd
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);

        maxVal = 1.1*max([medianOfMedianConcAccHd(idx1),medianOfMedianConcAccHd(idx2)]);
        minVal = 1.1*min([medianOfMedianConcAccHd(idx1),medianOfMedianConcAccHd(idx2)]);
        if minVal < 0.6*maxVal
            minVal = 0;
        end

        plot(medianOfMedianConcAccHd(idx1),medianOfMedianConcAccHd(idx2),'r*',...
             mean(medianOfMedianConcAccHd(idx1)),mean(medianOfMedianConcAccHd(idx2)),'g*',...
             [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
        title({'Concentration Accuracy','Resample Method','All Metabolites',sprintf('Pearson: %.4f',corr(medianOfMedianConcAccHd(idx1)',medianOfMedianConcAccHd(idx2)'))},'fontsize',18)
        xlabel(sprintf('%s',masterFunc),'fontsize',18)
        ylabel(sprintf('%s',compareFunc{1}),'fontsize',18)
        legend({'Metabolite Median','Mean of Metab. Medians'},'Location','EastOutside','fontsize',18)
        axis square
        axis([minVal, maxVal, minVal, maxVal])

        fileName = sprintf('%s/scatter_concAccHd_%s-v-%s_',plotDir,compareFunc{1},masterFunc);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Scatter plot for %s vs %s, all metabolites: Concentration Accuracy\n',compareFunc{1},masterFunc)
    end

    % derivAccHd
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);

        maxVal = 1.1*max([medianOfMedianDerivAccHd(idx1),medianOfMedianDerivAccHd(idx2)]);
        minVal = 1.1*min([medianOfMedianDerivAccHd(idx1),medianOfMedianDerivAccHd(idx2)]);
        if minVal < 0.6*maxVal
            minVal = 0;
        end

        plot(medianOfMedianDerivAccHd(idx1),medianOfMedianDerivAccHd(idx2),'r*',...
             mean(medianOfMedianDerivAccHd(idx1)),mean(medianOfMedianDerivAccHd(idx2)),'g*',...
             [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
        title({'Derivative Accuracy','Resample Method','All Metabolites',sprintf('Pearson: %.4f',corr(medianOfMedianDerivAccHd(idx1)',medianOfMedianDerivAccHd(idx2)'))},'fontsize',18)
        xlabel(sprintf('%s',masterFunc),'fontsize',18)
        ylabel(sprintf('%s',compareFunc{1}),'fontsize',18)
        legend({'Metabolite Median','Mean of Metab. Medians'},'Location','EastOutside','fontsize',18)
        axis square
        axis([minVal, maxVal, minVal, maxVal])

        fileName = sprintf('%s/derivAccHd_%s-v-%s_',plotDir,compareFunc{1},masterFunc);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Scatter plot for %s vs %s, all metabolites: Derivative Accuracy\n',compareFunc{1},masterFunc)
    end

    % concRobustness
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);

        maxVal = 1.1*max([medianResampleConcRobustness(idx1),medianResampleConcRobustness(idx2)]);
        minVal = 1.1*min([medianResampleConcRobustness(idx1),medianResampleConcRobustness(idx2)]);
        if minVal < 0.6*maxVal
            minVal = 0;
        end

        plot(medianResampleConcRobustness(idx1),medianResampleConcRobustness(idx2),'r*',...
             mean(medianResampleConcRobustness(idx1)),mean(medianResampleConcRobustness(idx2)),'g*',...
             [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
        title({'Concentration Robustness','Resample Method','All Metabolites',sprintf('Pearson: %.4f',corr(medianResampleConcRobustness(idx1)',medianResampleConcRobustness(idx2)'))},'fontsize',18)
        xlabel(sprintf('%s',masterFunc),'fontsize',18)
        ylabel(sprintf('%s',compareFunc{1}),'fontsize',18)
        legend({'Metabolite Median','Mean of Metab. Medians'},'Location','EastOutside','fontsize',18)
        axis square
        axis([minVal, maxVal, minVal, maxVal])

        fileName = sprintf('%s/scatter_concRobustness_%s-v-%s_',plotDir,compareFunc{1},masterFunc);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Scatter plot for %s vs %s, all metabolites: Concentration Robustness\n',compareFunc{1},masterFunc)
    end

    % derivRobustness
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);

        maxVal = 1.1*max([medianResampleDerivRobustness(idx1),medianResampleDerivRobustness(idx2)]);
        minVal = 1.1*min([medianResampleDerivRobustness(idx1),medianResampleDerivRobustness(idx2)]);
        if minVal < 0.6*maxVal
            minVal = 0;
        end

        plot(medianResampleDerivRobustness(idx1),medianResampleDerivRobustness(idx2),'r*',...
             mean(medianResampleDerivRobustness(idx1)),mean(medianResampleDerivRobustness(idx2)),'g*',...
             [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
        title({'Derivative Robusntess','Resample Method','All Metabolites',sprintf('Pearson: %.4f',corr(medianResampleDerivRobustness(idx1)',medianResampleDerivRobustness(idx2)'))},'fontsize',18)
        xlabel(sprintf('%s',masterFunc),'fontsize',18)
        ylabel(sprintf('%s',compareFunc{1}),'fontsize',18)
        legend({'Metabolite Median','Mean of Metab. Medians'},'Location','EastOutside','fontsize',18)
        axis square
        axis([minVal, maxVal, minVal, maxVal])

        fileName = sprintf('%s/derivRobustness_%s-v-%s_',plotDir,compareFunc{1},masterFunc);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Scatter plot for %s vs %s, all metabolites: Derivative Robustness\n',compareFunc{1},masterFunc)
    end
    
    
    % Now, let's break it down for each metabolite
    for metab_k = unique(currentMetabNum)

        fprintf('\t\t...Metabolite %d\n',metab_k);

        % Which parts of my compilation list do I care about atm?
        idx1 = find(all([strcmp(currentFunc,masterFunc);currentMetabNum==metab_k],1));
        idx2 = find(all([strcmp(currentFunc,compareFunc{1});currentMetabNum==metab_k],1));

        if length(idx1) > 1 || length(idx2)>1
            fprintf('\t\tWarning! Repeat datasets!\n')
        end

        % concAccHd
        try
            set(0,'DefaultFigureVisible','off')
            h = figure('units','normalized','outerposition',[0 0 1 1]);

            maxVal = 1.1*max([medianResampleConcAccHd{idx1}, medianResampleConcAccHd{idx2}]);
            minVal = 0.9*min([medianResampleConcAccHd{idx1}, medianResampleConcAccHd{idx2}]);
            if minVal < 0.6*maxVal
                minVal = 0;
            end

            plot(medianResampleConcAccHd{idx1},medianResampleConcAccHd{idx2},'r*',...
                 mean(medianResampleConcAccHd{idx1}),mean(medianResampleConcAccHd{idx2}),'g*',...
                 [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
            title({'Concentration Accuracy','Resample Method',sprintf('Metab %02d: %s',metab_k,currentMetabName{idx1(1)}),sprintf('Pearson: %.4f',corr(medianResampleConcAccHd{idx1}',medianResampleConcAccHd{idx2}'))},'fontsize',18)
            xlabel(sprintf('%s',masterFunc),'fontsize',18)
            ylabel(sprintf('%s',compareFunc{1}),'fontsize',18)
            legend({'Resample Median','Mean of Resample Medians'},'Location','EastOutside','fontsize',18)
            axis square
            axis([minVal, maxVal, minVal, maxVal])

            fileName = sprintf('%s/scatter_concAccHd_%s-v-%s_metab%02d',plotDir,compareFunc{1},masterFunc,metab_k);
            print(h,'-dpng','-r600',fileName);
            close(h)
            set(0,'DefaultFigureVisible','on')
        catch
            close(h)
            set(0,'DefaultFigureVisible','on')
            fprintf('Error: Scatter plot for %s vs %s, metabolites %02d: Concentration Accuracy\n',compareFunc{1},masterFunc,metab_k)
        end

        % derivAccHd
        try
            set(0,'DefaultFigureVisible','off')
            h = figure('units','normalized','outerposition',[0 0 1 1]);

            maxVal = 1.1*max([medianResampleDerivAccHd{idx1}, medianResampleDerivAccHd{idx2}]);
            minVal = 0.9*min([medianResampleDerivAccHd{idx1}, medianResampleDerivAccHd{idx2}]);
            if minVal < 0.6*maxVal
                minVal = 0;
            end

            plot(medianResampleDerivAccHd{idx1},medianResampleDerivAccHd{idx2},'r*',...
                 mean(medianResampleDerivAccHd{idx1}),mean(medianResampleDerivAccHd{idx2}),'g*',...
                 [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
            title({'Derivative Accuracy','Resample Method',sprintf('Metab %02d: %s',metab_k,currentMetabName{idx1(1)}),sprintf('Pearson: %.4f',corr(medianResampleDerivAccHd{idx1}',medianResampleDerivAccHd{idx2}'))},'fontsize',18)
            xlabel(sprintf('%s',masterFunc),'fontsize',18)
            ylabel(sprintf('%s',compareFunc{1}),'fontsize',18)
            legend({'Resample Median','Mean of Resample Medians'},'Location','EastOutside','fontsize',18)
            axis square
            axis([minVal, maxVal, minVal, maxVal])

            fileName = sprintf('%s/scatter_derivAccHd_%s-v-%s_metab%02d',plotDir,compareFunc{1},masterFunc,metab_k);
            print(h,'-dpng','-r600',fileName);
            close(h)
            set(0,'DefaultFigureVisible','on')
        catch
            close(h)
            set(0,'DefaultFigureVisible','on')
            fprintf('Error: Scatter plot for %s vs %s, metabolites %02d: Derivative Accuracy\n',compareFunc{1},masterFunc,metab_k)
        end
    end

end

clear('numMetabs','numFuncs','barFuncList');
