% Made to be called by compareSolversResample
% Generates scatterplots comparing the resampling method and the direct fit method for each function
% This script generates the scatterplots for a particualar metabolite/function

plotDir = 'resamplePlots_directVsResample';


if ~exist(plotDir,'dir')
    mkdir(plotDir)
end

fprintf('\t\t...Generating Scatter Plots: Direct vs Resample\n')


% concAccHd
try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);

    maxVal = 1.1*max([medianResampleConcAccHd{set_k},directConcAccHd{set_k}]);
    minVal = 0.9*min([medianResampleConcAccHd{set_k},directConcAccHd{set_k}]);
    if minVal < 0.6*maxVal
        minVal = 0;
    end
    
    plot(medianResampleConcAccHd{set_k},directConcAccHd{set_k},'bx',...
         mean(medianResampleConcAccHd{set_k}),mean(directConcAccHd{set_k}),'r*',...
         [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
    title({'Direct vs Resample Method','Concentration Accuracy',sprintf('Function: %s',currentFunc{set_k}),sprintf('Metabolite %02d: %s',metab_k,currentMetabName{set_k}),sprintf('Pearson: %.4f',corr(medianResampleConcAccHd{set_k}',directConcAccHd{set_k}'))},'fontsize',18)
    xlabel('Resample Median','fontsize',18)
    ylabel('Direct Fit','fontsize',18)
    axis([minVal, maxVal, minVal, maxVal])
    axis square

    fileName = sprintf('%s/directVsResample_%s_concAccHd_metab%02d',plotDir,currentFunc{set_k},metab_k);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Scatter plot - Direct vs Resample - Function %s - Metabolite %d - Concentration Accuracy\n',currentFunc{set_k},currentMetabNum(set_k))
end


% derivAccHd
try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);

    maxVal = 1.1*max([medianResampleDerivAccHd{set_k},directDerivAccHd{set_k}]);
    minVal = 0.9*min([medianResampleDerivAccHd{set_k},directDerivAccHd{set_k}]);
    if minVal < 0.6*maxVal
        minVal = 0;
    end
    
    plot(medianResampleDerivAccHd{set_k},directDerivAccHd{set_k},'bx',...
         mean(medianResampleDerivAccHd{set_k}),mean(directDerivAccHd{set_k}),'r*',...
         [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
    title({'Direct vs Resample Method','Derivative Accuracy',sprintf('Function: %s',currentFunc{set_k}),sprintf('Metabolite %02d: %s',metab_k,currentMetabName{set_k}),sprintf('Pearson: %.4f',corr(medianResampleDerivAccHd{set_k}',directDerivAccHd{set_k}'))},'fontsize',18)
    xlabel('Resample Median','fontsize',18)
    ylabel('Direct Fit','fontsize',18)
    axis([minVal, maxVal, minVal, maxVal])
    axis square

    fileName = sprintf('%s/directVsResample_%s_derivAccHd_metab%02d',plotDir,currentFunc{set_k},metab_k);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Scatter plot - Direct vs Resample - Function %s - Metabolite %d - Derivative Accuracy\n',currentFunc{set_k},currentMetabNum(set_k))
end
