% Made to be called by compareSolversResample
% Generates scatterplots comparing the resampling method and the direct fit method for each function
% This script generates the scatterplots for a each function

plotDir = 'resamplePlots_directVsResample';


if ~exist(plotDir,'dir')
    mkdir(plotDir)
end

compareFuncList =  unique(currentFunc,'stable');

fprintf('Generating Scatter Plots: Direct vs Resample\n')


for compareFunc = compareFuncList
    
    fprintf('\t...Plotting Function: %s\n',compareFunc{1})
    
    idxFcn = find(strcmp(currentFunc,compareFunc{1}));


    % concAccHd
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);

        maxVal = 1.1*max([medianOfMedianConcAccHd(idxFcn),medianDirectConcAccHd(idxFcn)]);
        minVal = 0.9*min([medianOfMedianConcAccHd(idxFcn),medianDirectConcAccHd(idxFcn)]);
        if minVal < 0.6*maxVal
            minVal = 0;
        end

        plot(medianOfMedianConcAccHd(idxFcn),medianDirectConcAccHd(idxFcn),'gx',...
             mean(medianOfMedianConcAccHd(idxFcn)),mean(medianDirectConcAccHd(idxFcn)),'r*',...
             [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
        title({'Direct vs Resample Method','Concentration Accuracy',sprintf('Function: %s',compareFunc{1}),'All Metabolites',sprintf('Pearson: %.4f',corr(medianOfMedianConcAccHd(idxFcn)',medianDirectConcAccHd(idxFcn)'))},'fontsize',18)
        xlabel('Resample Median','fontsize',18)
        ylabel('Direct Fit','fontsize',18)
        legend({'Metabolite Median','Mean of Metab. Medians'},'Location','EastOutside','fontsize',18)
        axis([minVal, maxVal, minVal, maxVal])
        axis square

        fileName = sprintf('%s/directVsResample_%s_concAccHd',plotDir,compareFunc{1});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Scatter plot - Direct vs Resample - Function %s - Concentration Accuracy\n',compareFunc{1})
    end


    % derivAccHd
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);

        maxVal = 1.1*max([medianOfMedianDerivAccHd(idxFcn),medianDirectDerivAccHd(idxFcn)]);
        minVal = 0.9*min([medianOfMedianDerivAccHd(idxFcn),medianDirectDerivAccHd(idxFcn)]);
        if minVal < 0.6*maxVal
            minVal = 0;
        end

        plot(medianOfMedianDerivAccHd(idxFcn),medianDirectDerivAccHd(idxFcn),'gx',...
             mean(medianOfMedianDerivAccHd(idxFcn)),mean(medianDirectDerivAccHd(idxFcn)),'r*',...
             [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
        title({'Direct vs Resample Method','Derivative Accuracy',sprintf('Function: %s',compareFunc{1}),'All Metabolites',sprintf('Pearson: %.4f',corr(medianOfMedianDerivAccHd(idxFcn)',medianDirectDerivAccHd(idxFcn)'))},'fontsize',18)
        xlabel('Resample Median','fontsize',18)
        ylabel('Direct Fit','fontsize',18)
        legend({'Metabolite Median','Mean of Metab. Medians'},'Location','EastOutside','fontsize',18)
        axis([minVal, maxVal, minVal, maxVal])
        axis square

        fileName = sprintf('%s/directVsResample_%s_derivAccHd',plotDir,compareFunc{1});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Scatter plot - Direct vs Resample - Function %s - Derivative Accuracy\n',compareFunc{1})
    end



    % concRobustness
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);

        maxVal = 1.1*max([medianResampleConcRobustness(idxFcn),directConcRobustness(idxFcn)]);
        minVal = 0.9*min([medianResampleConcRobustness(idxFcn),directConcRobustness(idxFcn)]);
        if minVal < 0.6*maxVal
            minVal = 0;
        end

        plot(medianResampleConcRobustness(idxFcn),directConcRobustness(idxFcn),'gx',...
             mean(medianResampleConcRobustness(idxFcn)),mean(directConcRobustness(idxFcn)),'r*',...
             [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
        title({'Direct vs Resample Method','Concentration Robustness',sprintf('Function: %s',compareFunc{1}),'All Metabolites',sprintf('Pearson: %.4f',corr(medianResampleConcRobustness(idxFcn)',directConcRobustness(idxFcn)'))},'fontsize',18)
        xlabel('Resample Median','fontsize',18)
        ylabel('Direct Fit','fontsize',18)
        legend({'Metabolite Median','Mean of Metab. Medians'},'Location','EastOutside','fontsize',18)
        axis([minVal, maxVal, minVal, maxVal])
        axis square

        fileName = sprintf('%s/directVsResample_%s_concRobustness',plotDir,compareFunc{1});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Scatter plot - Direct vs Resample - Function %s - Concentration Robustness\n',compareFunc{1})
    end


    % derivRobustness
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);

        maxVal = 1.1*max([medianResampleDerivRobustness(idxFcn),directDerivRobustness(idxFcn)]);
        minVal = 0.9*min([medianResampleDerivRobustness(idxFcn),directDerivRobustness(idxFcn)]);
        if minVal < 0.6*maxVal
            minVal = 0;
        end

        plot(medianResampleDerivRobustness(idxFcn),directDerivRobustness(idxFcn),'gx',...
             mean(medianResampleDerivRobustness(idxFcn)),mean(directDerivRobustness(idxFcn)),'r*',...
             [minVal, maxVal],[minVal, maxVal],'k-','linewidth',2)
        title({'Direct vs Resample Method','Derivative Robustness',sprintf('Function: %s',compareFunc{1}),'All Metabolites',sprintf('Pearson: %.4f',corr(medianResampleDerivRobustness(idxFcn)',directDerivRobustness(idxFcn)'))},'fontsize',18)
        xlabel('Resample Median','fontsize',18)
        ylabel('Direct Fit','fontsize',18)
        legend({'Metabolite Median','Mean of Metab. Medians'},'Location','EastOutside','fontsize',18)
        axis([minVal, maxVal, minVal, maxVal])
        axis square

        fileName = sprintf('%s/directVsResample_%s_derivRobustness',plotDir,compareFunc{1});
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Scatter plot - Direct vs Resample - Function %s - Derivative Robustness\n',compareFunc{1})
    end
    
end

clear compareFuncList
