% Made to be called from compareBfSweep
% Generates plots comparing metrics against different bF values.

resultsDir = 'resultsPlots';


if ~exist(resultsDir,'dir')
    mkdir(resultsDir)
end
close all
set(0,'DefaultFigureVisible','off')

numBF = length(unique(bFList));
metabIndexList = unique(currentMetabNum);
numMetab = length(unique(metabIndexList));

fprintf('Plotting Metrics vs BF (linear y-scale)\n')

try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);

    hold on
    plot(unique(bFList,'stable'), reshape(median(rmsdMatrix,1),numBF,numMetab),'k-','linewidth',2)
    title({'Fitting RMSE vs bF','Average across noisy datasets for All Metabolites'},'fontsize',18)
    xlabel('bF','fontsize',18)
    ylabel('RMSE','fontsize',18)
    xlim([0 inf])
    ylim([0 inf])

    fileName = sprintf('%s/median_RMSE_metabAll',resultsDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Average RMSE, All metabolites\n')
end



try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);

    hold on
    plot(unique(bFList,'stable'), reshape(medianDirectConcAccHd,numBF,numMetab),'k-','linewidth',2)
    title({'Concentration Interpolation Accuracy vs bF','Average across noisy datasets for all metabolites'},'fontsize',18)
    xlabel('bF','fontsize',18)
    ylabel('Concentration Error','fontsize',18)
    xlim([0 inf])
    ylim([0 inf])
    

    fileName = sprintf('%s/median_concAccHd_metabAll',resultsDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Average Concentration Interpolation Accuracy, all metabolites\n')
end


try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);

    hold on
    plot(unique(bFList,'stable'), reshape(medianDirectDerivAccHd,numBF,numMetab),'k-','linewidth',2)
    title({'Derivative Interpolation Accuracy vs bF','Average across noisy datasets for all metabolites'},'fontsize',18)
    xlabel('bF','fontsize',18)
    ylabel('Derivative Error','fontsize',18)
    xlim([0 inf])
    ylim([0 inf])
    

    fileName = sprintf('%s/median_derivAccHd_metabAll',resultsDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Average Derivative Inerpolation Accuracy, all metabolites\n')
end



try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);

    hold on
    plot(unique(bFList,'stable'), reshape(directConcRobustness,numBF,numMetab),'k-','linewidth',2)
    title({'Concentration Robustness vs bF','Average across noisy datasets for all metabolites'},'fontsize',18)
    xlabel('bF','fontsize',18)
    ylabel('Concentration Variability','fontsize',18)
    xlim([0 inf])
    ylim([0 inf])
    

    fileName = sprintf('%s/median_concRobustness_metabAll',resultsDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Average Concentration Robustness, all metabolites\n')
end


try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);

    hold on
    plot(unique(bFList,'stable'), reshape(directDerivRobustness,numBF,numMetab),'k-','linewidth',2)
    title({'Derivative Robustness vs bF','Average across noisy datasets for all metabolites'},'fontsize',18)
    xlabel('bF','fontsize',18)
    ylabel('Derivative Variability','fontsize',18)
    xlim([0 inf])
    ylim([0 inf])
    

    fileName = sprintf('%s/median_derivRobustness_metabAll',resultsDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Average Derivative Robustness, all metabolites\n')
end


for metab_k = metabIndexList
    
    idxList = find(currentMetabNum==metab_k);
    
    fprintf('\t... Metabolite %02d\n',metab_k)

    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        
        hold on
        plot(bFList(idxList), median(rmsdMatrix(:,idxList),1),'k-','linewidth',2)
        title({'Fitting RMSE vs bF',sprintf('Average across noisy datasets for Metabolite %02d',metab_k)},'fontsize',18)
        xlabel('bF','fontsize',18)
        ylabel('RMSE','fontsize',18)
        

        fileName = sprintf('%s/median_RMSE_metab%02d',resultsDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Average RMSE, metabolite %02d\n',metab_k)
    end
    
    
    
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        
        hold on
        plot(bFList(idxList), medianDirectConcAccHd(idxList),'k-','linewidth',2)
        title({'Concentration Interpolation Accuracy vs bF',sprintf('Average across noisy datasets for Metabolite %02d',metab_k)},'fontsize',18)
        xlabel('bF','fontsize',18)
        ylabel('Concentration Error','fontsize',18)
        

        fileName = sprintf('%s/median_concAccHd_metab%02d',resultsDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Average Concentration Interpolation Accuracy, metabolite %02d\n',metab_k)
    end
    
    
    
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        
        hold on
        plot(bFList(idxList), medianDirectDerivAccHd(idxList),'k-','linewidth',2)
        title({'Derivative Interpolation Accuracy vs bF',sprintf('Average across noisy datasets for Metabolite %02d',metab_k)},'fontsize',18)
        xlabel('bF','fontsize',18)
        ylabel('Derivative Error','fontsize',18)
        

        fileName = sprintf('%s/median_derivAccHd_metab%02d',resultsDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Average Derivative Inerpolation Accuracy, metabolite %02d\n',metab_k)
    end
    
   
    
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        
        hold on
        plot(bFList(idxList), directConcRobustness(idxList),'k-','linewidth',2)
        title({'Concentration Robustness vs bF',sprintf('Average across noisy datasets for Metabolite %02d',metab_k)},'fontsize',18)
        xlabel('bF','fontsize',18)
        ylabel('Concentration Variability','fontsize',18)
        

        fileName = sprintf('%s/median_concRobustness_metab%02d',resultsDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Average Concentration Robustness, metabolite %02d\n',metab_k)
    end
    

    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        
        hold on
        plot(bFList(idxList), directDerivRobustness(idxList),'k-','linewidth',2)
        title({'Derivative Robustness vs bF',sprintf('Average across noisy datasets for Metabolite %02d',metab_k)},'fontsize',18)
        xlabel('bF','fontsize',18)
        ylabel('Derivative Variability','fontsize',18)
        

        fileName = sprintf('%s/median_derivRobustness_metab%02d',resultsDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Average Derivative Robustness, metabolite %02d\n',metab_k)
    end
    
end


set(0,'DefaultFigureVisible','on')