clc; clear; close all; set(0,'DefaultFigureVisible','on')

% What files are we importing in?
dataFile = 'HynneSmooth.txt';

% Define our noisy dataset
numIters = 500;
CoV = .15;
numReplicates = 5;
numSamples = 61; % 0 to 15m, at 0.25m intervals
timeUnit = 'min';
concUnit = 'mM';


% Re-Order of metabolites from the COPASI output
columnList = 2:23;

%	2	GlcX	 - 	Extracellular glucose
%	3	Glc	     - 	Cytosolic glucose
%	4	G6P	     - 	Glucose-6-Phosphate
%	5	F6P	     - 	Fructose-6-Phosphate
%	6	FBP	     - 	Fructose 1,6-bisphosphate
%	7	DHAP	 - 	Dihydroxyacetone phosphate
%	8	GAP	     - 	Glyceraldehyde 3-phosphate
%	9	BPG	     - 	1,3-Bisphosphoglycerate
%	10	PEP	     - 	Phosphoenolpyruvate
%	11	Pyr	     - 	Pyruvate
%	12	ACA	     - 	Acetaldehyde
%	13	ACAX	 - 	Extracellular acetaldehyde
%	14	EtOH	 - 	EtOH
%	15	EtOHX	 - 	Extracellular ethanol
%	16	Glyc	 - 	Glycerol
%	17	GlycX	 - 	Extracellular glycerol
%	18	CNX	     - 	Extracellular cyanide
%	19	AMP	     - 	AMP
%	20	ADP	     - 	ADP
%	21	ATP	     - 	ATP
%	22	NAD	     - 	NAD
%	23	NADH	 - 	NADH


% Load in our data
dataStruct = importdata(dataFile);
    trueData = dataStruct.data(:,columnList);
    smoothTime = dataStruct.data(:,1);
    colNames = dataStruct.colheaders(columnList)';
    
% Take the derivative of the true, smooth data (Finite Difference Approx)
trueDataDeriv = (trueData(3:end,:) - trueData(1:end-2,:))./repmat((smoothTime(3:end) - smoothTime(1:end-2)),1,size(trueData,2));
derivSmoothTime = smoothTime(2:end-1);

% Get the data at sampling frequency
sampleTime = linspace(smoothTime(1),smoothTime(end),numSamples)';
[~, idxSample] =      min(abs(repmat(smoothTime,1,size(sampleTime,1))-repmat(sampleTime',size(smoothTime,1),1)));
[~, idxSampleDeriv] = min(abs(repmat(derivSmoothTime,1,size(sampleTime,1))-repmat(sampleTime',size(derivSmoothTime,1),1)));
noiselessData = trueData(idxSample,:);
noiselessDataDeriv = trueDataDeriv(idxSampleDeriv,:);

noisyDataMatrix = repmat({zeros(size(noiselessData))},numIters,1);

for iteration_k = 1:numIters

    % Reinitialize storage space...
    noisyData = zeros(size(noiselessData,1),size(noiselessData,2),numReplicates);

    % Generate the noisy measurements
    for j=1:size(noiselessData,2)
        for i = 1:size(noiselessData,1)

            for k = 1:numReplicates
                % Add noise to the original measurements
                noisyData(i,j,k) = CoV*noiselessData(i,j)*randn(1,1) + noiselessData(i,j);
            end

            % Get the average of the noisy data
            noisyDataMatrix{iteration_k}(i,j) = mean(noisyData(i,j,:));

        end
    end

end

% Save our results out
save('hynneNoisy.mat',...
     'numIters',...
     'CoV',...
     'numReplicates',...
     'timeUnit',...
     'concUnit',...
     'colNames',...
     'trueData',...
     'trueDataDeriv',...
     'noiselessData',...
     'noiselessDataDeriv',...
     'noisyDataMatrix',...
     'sampleTime',...
     'smoothTime',...
     'derivSmoothTime',...
     'idxSampleDeriv');
