clc; clear; close all; set(0,'DefaultFigureVisible','on')

% What files are we importing in?
dataFile = 'hynneSimulation.txt';
columnList = [6, 15, 25, 12, 17, 10, 11, 4, 23, 13, 5, 18, 14, 20, 26, 16, 2, 19, 21, 22, 24, 3];


plotDir = '.';
if ~exist(plotDir,'dir')
    mkdir(plotDir)
end

% Load in our data
dataStruct = importdata(dataFile);
    trueData = dataStruct.data(:,columnList);
    smoothTime = dataStruct.data(:,1);
    colNames = dataStruct.colheaders(columnList)';
    
    
tOffset = 70131;
tIdx = tOffset:tOffset+8230;

try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
    set(gca,'fontsize',18,'linewidth',2)
    box

    plot(smoothTime,trueData(:,1:16))
    title(sprintf('Time evolution of metabolites\ntowards steady oscillations'),'fontsize',18)
    xlabel('Time (min)','fontsize',18)
    ylabel('Concentration','fontsize',18)
    legend(colNames(1:16),'Location','EastOutside','Fontsize',10)

    fileName = 'hynne_Fig6_timeToSS.png';
    print(h,'-dpng','-r600',fileName)
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    fprintf('Error: Figure 6 plot')
    set(0,'DefaultFigureVisible','on')
end
    
try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
    set(gca,'fontsize',18,'linewidth',2)
    box

    plot(smoothTime(tIdx),trueData(tIdx,1:16))
    axis([smoothTime(tIdx(1)),smoothTime(tIdx(end)),0,5.5])
    title(sprintf('Reproduction of Hynne 2001:\nFigure 6 from SBML and Copasi'),'fontsize',18)
    xlabel('Time (min)','fontsize',18)
    ylabel('Concentration','fontsize',18)
    legend(colNames(1:16),'Location','EastOutside','Fontsize',10)

    fileName = 'hynne_Fig6_fromSBML-Copasi-Matlab.png';
    print(h,'-dpng','-r600',fileName)
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    fprintf('Error: Figure 6 plot')
    set(0,'DefaultFigureVisible','on')
end
