function calculateResampleParams(dataFileName,funcType,resultsDir)

    % Load in the appropriate datafile
    load(dataFileName);

    % Just in case we get lazy...
    if ~exist('resultsDir','var')
        resultsDir = 'output_resampleMethod';
    end
    
    if ~exist(resultsDir,'dir')
        mkdir(resultsDir);
    end

    % We'll be here FOREVER if we try doing multiple seeds...
    paramsResample.numTries = 1;
    paramsResample.bF = 0.5;
    paramsSuper.bF = 0.5;
    
    % Pre-allocate for the random data sets
    superParamSolution = zeros(7,numRandIters);
    superRmsd = inf(numRandIters,1);
    resampleParamSolution = cell(numRandIters,1);
    resampleRmsd = cell(numRandIters,1);
    runTime = cell(numRandIters,1);
    
    % For each of out random datasets
    for randData_j = 1:numRandIters

        fprintf('Noisy set %d/%d\n',randData_j,numRandIters)
        
        % First - get the "ideal" solution
        [superParamSolution(:,randData_j), superRmsd(randData_j)] = fitSmoothingFcn(sampleTime,baseNoisyData(:,randData_j),funcType,paramsSuper);
        
        % If it's the impulse, let's use the direct fits results to seed
        % the solver for the noisy datasets. This is reasonable because the
        % direct fit results are still available in practice as well.
        paramsResample.pInit = superParamSolution(:,randData_j);
            
        % Pre-allocate for the resampling solutions
        resampleParamSolution{randData_j} = zeros(7,numResampleIters);
        resampleRmsd{randData_j} = inf(numResampleIters,1);
        runTime{randData_j} = zeros(numResampleIters,1);

        % Calculate the best fit for each resampling time course
        for iteration_k = 1:numResampleIters

            fprintf('\tIteration %d/%d\n',iteration_k,numResampleIters)
            ticLoop = tic;
            
            % Fit the function we picked for this call
            [resampleParamSolution{randData_j}(:,iteration_k), resampleRmsd{randData_j}(iteration_k)] = fitSmoothingFcn(sampleTime,noisyDataMatrix{iteration_k}(:,randData_j),funcType,paramsResample);

            % For kicks - how long did this take us?
            runTime{randData_j}(iteration_k) = toc(ticLoop);
            
        % Now save out our data for this metab and run conditions!!
        save(sprintf('%s/resampleFitParams_%s_metab%02d.mat',resultsDir,funcType,metabNum),...
                    'dataFileName',...
                    'funcType',...
                    'CoV',...
                    'numReplicates',...
                    'numRandIters',...
                    'numResampleIters',...
                    'superParamSolution',...
                    'superRmsd',...
                    'resampleParamSolution',...
                    'resampleRmsd',...
                    'runTime');
                
        end
    end
end