clc; clear; close all; set(0,'DefaultFigureVisible','on')

% Specify what we're looking for right here up top
baseDatasetFileName = '../hynneData/hynneNoisy.mat';
fileNameStem = '../hynneFit/output_hynneResample/resampleFitParams';
metabIndexList = [1:16, 18:22];


ticStart = tic;

fprintf('Generating Resampling Method plots from %s\n\n',baseDatasetFileName);

fullFuncList = {'poly2';
                'poly3';
                'poly4';
                'poly5';
                'rat11';
                'rat22';
                'rat31';
                'impls'};

% Pull the master dataset
baseDataset = load(baseDatasetFileName);
metabNameList = baseDataset.colNames;
noiseCoV = baseDataset.CoV;

% Get time arrays
sampleTime = baseDataset.sampleTime;
smoothTime = baseDataset.smoothTime;
smoothTimeDeriv = baseDataset.derivSmoothTime;
hdTime = linspace(sampleTime(1),sampleTime(end),10*(length(sampleTime)-1)+1)';
timeUnit = baseDataset.timeUnit;

% Get our true data arrays
[~, idxHdConc] = min(abs(repmat(smoothTime,1,size(hdTime,1))-repmat(hdTime',size(smoothTime,1),1)));
[~, idxHdDeriv] = min(abs(repmat(smoothTimeDeriv,1,size(hdTime,1))-repmat(hdTime',size(smoothTimeDeriv,1),1)));

trueConcSmooth = baseDataset.trueData;
trueDerivSmooth = baseDataset.trueDataDeriv;
trueConcSample = baseDataset.noiselessData;
trueDerivSample = baseDataset.trueDataDeriv(baseDataset.idxSampleDeriv,:);
trueConcHd = baseDataset.trueData(idxHdConc,:);
trueDerivHd = baseDataset.trueDataDeriv(idxHdDeriv,:);
concUnit = baseDataset.concUnit;

% Final clean-up/set-up
clear baseDataset

set_k = 1;


% Loop through our functions
for func_k = fullFuncList'
    
    % Which function are we checking right now?
    fprintf('Reading Function: %s\n',func_k{1});
    
    % Let's run through out list of metabs
    for metab_k = metabIndexList

        % More robust handling for when cases screw up
        try

            % Get the parameters for this particlar function & metabolite
            load(sprintf('%s_%s_metab%02d.mat',fileNameStem,func_k{1},metab_k));
            
            % Record info about which function and metabolite we're
            % looking at, for future reference
            currentFunc{set_k} = func_k{1};
            currentMetabNum(set_k) = metab_k;
            currentMetabName{set_k} = metabNameList{metab_k};
            fprintf('\tMetab %02d - %s\n',metab_k,currentMetabName{set_k});

            % Now let's get cracking
            directConcSample = zeros(length(sampleTime),numRandIters);
            directConcHd = zeros(length(hdTime),numRandIters);
            directConcSmooth = zeros(length(smoothTime),numRandIters);
            directDerivSample = zeros(length(sampleTime),numRandIters);
            directDerivHd = zeros(length(hdTime),numRandIters);
            directDerivSmooth = zeros(length(smoothTimeDeriv),numRandIters);

            resampleConcSample = cell(numRandIters,1);
            resampleConcHd = cell(numRandIters,1);
            resampleConcSmooth = cell(numRandIters,1);
            resampleDerivSample = cell(numRandIters,1);
            resampleDerivHd = cell(numRandIters,1);
            resampleDerivSmooth = cell(numRandIters,1);

            medianResampleConcSample = zeros(length(sampleTime),numRandIters);
            medianResampleConcHd = zeros(length(hdTime),numRandIters);
            medianResampleConcSmooth = zeros(length(smoothTime),numRandIters);
            medianResampleDerivSample = zeros(length(sampleTime),numRandIters);
            medianResampleDerivHd = zeros(length(hdTime),numRandIters);
            medianResampleDerivSmooth = zeros(length(smoothTimeDeriv),numRandIters);


            % For each "metabolite" --> base noisy data set
            % 1) Regenerate time courses for the direct fit
            % ('Super Fits')
            for noisySet_k = 1:numRandIters
                directConcSample(:,noisySet_k) = evalSmoothingFcn(superParamSolution(:,noisySet_k),sampleTime,currentFunc{set_k});
                directConcHd(:,noisySet_k) = evalSmoothingFcn(superParamSolution(:,noisySet_k),hdTime,currentFunc{set_k});
                directConcSmooth(:,noisySet_k) = evalSmoothingFcn(superParamSolution(:,noisySet_k),smoothTime,currentFunc{set_k});
                directDerivSample(:,noisySet_k) = evalSmoothingDeriv(superParamSolution(:,noisySet_k),sampleTime,currentFunc{set_k});
                directDerivHd(:,noisySet_k) = evalSmoothingDeriv(superParamSolution(:,noisySet_k),hdTime,currentFunc{set_k});
                directDerivSmooth(:,noisySet_k) = evalSmoothingDeriv(superParamSolution(:,noisySet_k),smoothTimeDeriv,currentFunc{set_k});

                resampleConcSample{noisySet_k} = zeros(length(sampleTime),numResampleIters);
                resampleConcHd{noisySet_k}  = zeros(length(hdTime),numResampleIters);
                resampleConcSmooth{noisySet_k}  = zeros(length(smoothTime),numResampleIters);
                resampleDerivSample{noisySet_k}  = zeros(length(sampleTime),numResampleIters);
                resampleDerivHd{noisySet_k}  = zeros(length(hdTime),numResampleIters);
                resampleDerivSmooth{noisySet_k}  = zeros(length(smoothTimeDeriv),numResampleIters);

                for resampleSet_k = 1:numResampleIters
                    % 2) Regenerate time courses for each of the resampled fits
                    % ('Resample Fits')
                    resampleConcSample{noisySet_k}(:,resampleSet_k) = evalSmoothingFcn(resampleParamSolution{noisySet_k}(:,resampleSet_k),sampleTime,currentFunc{set_k});
                    resampleConcHd{noisySet_k}(:,resampleSet_k) = evalSmoothingFcn(resampleParamSolution{noisySet_k}(:,resampleSet_k),hdTime,currentFunc{set_k});
                    resampleConcSmooth{noisySet_k}(:,resampleSet_k) = evalSmoothingFcn(resampleParamSolution{noisySet_k}(:,resampleSet_k),smoothTime,currentFunc{set_k});
                    resampleDerivSample{noisySet_k}(:,resampleSet_k) = evalSmoothingDeriv(resampleParamSolution{noisySet_k}(:,resampleSet_k),sampleTime,currentFunc{set_k});
                    resampleDerivHd{noisySet_k}(:,resampleSet_k) = evalSmoothingDeriv(resampleParamSolution{noisySet_k}(:,resampleSet_k),hdTime,currentFunc{set_k});
                    resampleDerivSmooth{noisySet_k}(:,resampleSet_k) = evalSmoothingDeriv(resampleParamSolution{noisySet_k}(:,resampleSet_k),smoothTimeDeriv,currentFunc{set_k});
                end

                % 3) Also Calculate the median behavior of the resampled fits
                % ('Median Fits')
                medianResampleConcSample(:,noisySet_k) = median(resampleConcSample{noisySet_k},2);
                medianResampleConcHd(:,noisySet_k) = median(resampleConcHd{noisySet_k},2);
                medianResampleConcSmooth(:,noisySet_k) = median(resampleConcSmooth{noisySet_k},2);
                medianResampleDerivSample(:,noisySet_k) = median(resampleDerivSample{noisySet_k},2);
                medianResampleDerivHd(:,noisySet_k) = median(resampleDerivHd{noisySet_k},2);
                medianResampleDerivSmooth(:,noisySet_k) = median(resampleDerivSmooth{noisySet_k},2);

            end

            
            % We have everything we need to plot trajectories!
            try
                plotTrajectoriesResample
            end


            % Some scaling and penalty factors for our metrics
            denominator = length(sampleTime)-nnz(~isnan(superParamSolution(:,1)));
            hdDenom = length(hdTime) * ((length(sampleTime)-nnz(~isnan(superParamSolution(:,1))))/length(sampleTime));
            
            concScaleSample = sqrt(mean((trueConcSample(:,metab_k)).^2));
            derivScaleSample = sqrt(mean((trueDerivSample(:,metab_k)).^2));
            concScaleHd = sqrt(mean((trueConcHd(:,metab_k)).^2));
            derivScaleHd = sqrt(mean((trueDerivHd(:,metab_k)).^2));
            
            
            % Calculate the performance of the direct method
            % Error metrics
            directConcAccHd{set_k} = sqrt(sum((directConcHd - repmat(trueConcHd(:,metab_k),1,numRandIters)).^2,1))/(hdDenom*concScaleHd);
            directDerivAccHd{set_k} = sqrt(sum((directDerivHd - repmat(trueDerivHd(:,metab_k),1,numRandIters)).^2,1))/(hdDenom*derivScaleHd);
                        
            % Some of the plot methods are interested in the medians of the metrics
            medianDirectConcAccHd(set_k) = median(directConcAccHd{set_k},2);
            medianDirectDerivAccHd(set_k) = median(directDerivAccHd{set_k},2);

            % How consistent are my fits? --> Robustness of performance
            directConcDispersion(set_k) = median(sqrt(sum(((directConcHd - repmat(median(directConcHd,2),1,numRandIters)).^2)/hdDenom,1))/concScaleHd);
            directDerivDispersion(set_k) = median(sqrt(sum(((directDerivHd - repmat(median(directDerivHd,2),1,numRandIters)).^2)/hdDenom,1))/derivScaleHd);
            directConcRobustness(set_k) = mean(sqrt(sum(((directConcHd - repmat(median(directConcHd,2),1,numRandIters)).^2)/hdDenom,1))/concScaleHd);
            directDerivRobustness(set_k) = mean(sqrt(sum(((directDerivHd - repmat(median(directDerivHd,2),1,numRandIters)).^2)/hdDenom,1))/derivScaleHd);
            
            
            
            % Calculate the performance of the medianResample method
            % Error metrics
            medianResampleConcAccHd{set_k} = sqrt(sum((medianResampleConcHd - repmat(trueConcHd(:,metab_k),1,numRandIters)).^2,1))/(hdDenom*concScaleHd);
            medianResampleDerivAccHd{set_k} = sqrt(sum((medianResampleDerivHd - repmat(trueDerivHd(:,metab_k),1,numRandIters)).^2,1))/(hdDenom*derivScaleHd);

            % Some of the plot methods are interested in the medians of the metrics
            medianOfMedianConcAccHd(set_k) = median(medianResampleConcAccHd{set_k},2);
            medianOfMedianDerivAccHd(set_k) = median(medianResampleDerivAccHd{set_k},2);
            
            % How consistent are my fits? --> Robustness of performance
            medianResampleConcDispersion(set_k) = median(sqrt(sum(((medianResampleConcHd - repmat(median(medianResampleConcHd,2),1,numRandIters)).^2)/hdDenom,1))/concScaleHd);
            medianResampleDerivDispersion(set_k) = median(sqrt(sum(((medianResampleDerivHd - repmat(median(medianResampleDerivHd,2),1,numRandIters)).^2)/hdDenom,1))/derivScaleHd);
            medianResampleConcRobustness(set_k) = mean(sqrt(sum(((medianResampleConcHd - repmat(median(medianResampleConcHd,2),1,numRandIters)).^2)/hdDenom,1))/concScaleHd);
            medianResampleDerivRobustness(set_k) = mean(sqrt(sum(((medianResampleDerivHd - repmat(median(medianResampleDerivHd,2),1,numRandIters)).^2)/hdDenom,1))/derivScaleHd);
            

            % Generate scatter plots - compare resample vs direct for this function & metabolite
            try
                plotScatterGraphsResampleVsDirect
            end


            % Housecleaning in between calculations
            clear('directConcSample',...
                  'directConcSmooth',...
                  'directConcHd',...
                  'directDerivSample',...
                  'directDerivSmooth',...
                  'directDerivHd',...
                  'medianResampleConcSample',...
                  'medianResampleConcSmooth',...
                  'medianResampleConcHd',...
                  'medianResampleDerivSample',...
                  'medianResampleDerivSmooth',...
                  'medianResampleDerivHd',...
                  'resampleConcSample',...
                  'resampleConcSmooth',...
                  'resampleConcHd',...
                  'resampleDerivSample',...
                  'resampleDerivSmooth',...
                  'resampleDerivHd',...
                  'denominator',...
                  'hdDenom')

            % FINALLY - if we've made it got here, everything is hunky
            % dory, and we can save what we calculated for this set!
            set_k = set_k + 1;

        catch
            fprintf('\tWarning: Error during analysis of ''%s_%s_metab%02d.mat''\n',fileNameStem,func_k{1},metab_k);
        end
    end
end

save testMatResample

% Generate bar plots - compare resample across functions
try
    plotBarGraphsResample
end

% Generate scatter plots - compare resample across functions
try
    plotScatterGraphsResample
end

% Generate Rank Bar Plots and Table - compare across functions
try
    calcRankMetaMetricsResample
end

% Generate Rank Bar Plots and Table - compare across functions, method
try
    calcRankMetaMetricsResampleVsDirect
end

fprintf('\nAnalysis Complete.\n')
toc(ticStart)
fprintf('\n')
