% Made to be run by compareSolversDirect
% Generates bar plots comparing metrics across functions
    
plotDir = 'directPlots_bar';


if ~exist(plotDir,'dir')
    mkdir(plotDir)
end

% Get info about what we're plotting
% % numSpacerMetabs = min(currentMetabNum)-1;
numActualMetabs = length(unique(currentMetabNum));
actualMetabList = unique(currentMetabNum);
numFuncs = length(unique(currentFunc));
barFuncList = unique(currentFunc,'stable');

fprintf('Generating Bar Plots:\n\tOverall Average Performance\n')

% medianConcAccHd
try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
% %     bar(-log10([zeros(numSpacerMetabs,numFuncs); reshape(medianDirectConcAccHd,numActualMetabs,numFuncs)]))
    plot(actualMetabList,log10(reshape(medianDirectConcAccHd,numActualMetabs,numFuncs)),'linewidth',1,'linestyle','--','marker','s')
    title({'Direct Method','Concentration Accuracy'},'fontsize',18)
    xlabel('Metabolite','fontsize',18)
    ylabel('log_1_0(Error)','fontsize',18)
    xlim([min(actualMetabList),max(actualMetabList)])
    legend(barFuncList,'Location','EastOutside','fontsize',18)

    fileName = sprintf('%s/bar_noVariance_concAccHd_allMetab',plotDir);
    print(h,'-dpng','-r600',fileName);;
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar plot for all metabolites: Concentration Accuracy\n')
end

% medianDerivAccHd
try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
% %     bar(-log10([zeros(numSpacerMetabs,numFuncs); reshape(medianDirectDerivAccHd,numActualMetabs,numFuncs)]))
    plot(actualMetabList,log10(reshape(medianDirectDerivAccHd,numActualMetabs,numFuncs)),'linewidth',1,'linestyle','--','marker','s')
    title({'Direct Method','Derivative Accuracy'},'fontsize',18)
    xlabel('Metabolite','fontsize',18)
    ylabel('log_1_0(Error)','fontsize',18)
    xlim([min(actualMetabList),max(actualMetabList)])
    legend(barFuncList,'Location','EastOutside','fontsize',18)

    fileName = sprintf('%s/bar_noVariance_derivAccHd_allMetab',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar plot for all metabolites: Derivative Accuracy\n')
end

% medianConcRobustness
try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
% %     bar(-log10([zeros(numSpacerMetabs,numFuncs); reshape(directConcRobustness,numActualMetabs,numFuncs)]))
    plot(actualMetabList,log10(reshape(directConcRobustness,numActualMetabs,numFuncs)),'linewidth',1,'linestyle','--','marker','s')
    title({'Direct Method','Concentration Robustness'},'fontsize',18)
    xlabel('Metabolite','fontsize',18)
    ylabel('log_1_0(Variability)','fontsize',18)
    xlim([min(actualMetabList),max(actualMetabList)])
    legend(barFuncList,'Location','EastOutside','fontsize',18)

    fileName = sprintf('%s/bar_concRobustness_allMetab',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar plot for all metabolites: Concentration Robustness\n')
end

% medianDerivRobustness
try
    set(0,'DefaultFigureVisible','off')
    h = figure('units','normalized','outerposition',[0 0 1 1]);
% %     bar(-log10([zeros(numSpacerMetabs,numFuncs); reshape(directDerivRobustness,numActualMetabs,numFuncs)]))
    plot(actualMetabList,log10(reshape(directDerivRobustness,numActualMetabs,numFuncs)),'linewidth',1,'linestyle','--','marker','s')
    title({'Direct Method','Derivative Robustness'},'fontsize',18)
    xlabel('Metabolite','fontsize',18)
    ylabel('log_1_0(Variability)','fontsize',18)
    xlim([min(actualMetabList),max(actualMetabList)])
    legend(barFuncList,'Location','EastOutside','fontsize',18)

    fileName = sprintf('%s/bar_derivRobustness_allMetab',plotDir);
    print(h,'-dpng','-r600',fileName);
    close(h)
    set(0,'DefaultFigureVisible','on')
catch
    close(h)
    set(0,'DefaultFigureVisible','on')
    fprintf('Error: Bar plot for all metabolites: Derivative Robustness\n')
end

for metab_k = unique(currentMetabNum)

    fprintf('\t...Metabolite %02d\n',metab_k)

    idxMetab = find(currentMetabNum == metab_k);

    % concAccHd
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        barweb(medianDirectConcAccHd(idxMetab),directConcDispersion(idxMetab));
        title({'Direct Method','Concentration Accuracy'},'fontsize',18)
        xlabel(sprintf('Metabolite %02d: %s',metab_k,currentMetabName{idxMetab(1)}),'fontsize',18)
        set(gca,'fontsize',18)
        set(gca,'xticklabel',[])
        ylabel('Error','fontsize',18)
        legend(barFuncList ,'Location','EastOutside','fontsize',18)

        fileName = sprintf('%s/bar_concAccHd_metab%02d',plotDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Bar plot for metabolite %02d: Concentration Accuracy\n',metab_k)
    end

    % derivAccHd
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        barweb(medianDirectDerivAccHd(idxMetab),directDerivDispersion(idxMetab)); 
        title({'Direct Method','Derivative Accuracy'},'fontsize',18)
        xlabel(sprintf('Metabolite %02d: %s',metab_k,currentMetabName{idxMetab(1)}),'fontsize',18)
        set(gca,'fontsize',18)
        set(gca,'xticklabel',[])
        ylabel('Error','fontsize',18)
        legend(barFuncList ,'Location','EastOutside','fontsize',18)

        fileName = sprintf('%s/bar_derivAccHd_metab%02d',plotDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Bar plot for metabolite %02d: Derivative Accuracy\n',metab_k)
    end

    % concAccHd
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        barweb(medianDirectConcAccHd(idxMetab),zeros(size(directConcDispersion(idxMetab))));
        title({'Direct Method','Concentration Accuracy'},'fontsize',18)
        xlabel(sprintf('Metabolite %02d: %s',metab_k,currentMetabName{idxMetab(1)}),'fontsize',18)
        set(gca,'fontsize',18)
        set(gca,'xticklabel',[])
        ylabel('Error','fontsize',18)
        legend(barFuncList ,'Location','EastOutside','fontsize',18)

        fileName = sprintf('%s/bar_noVariance_concAccHd_metab%02d',plotDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Bar plot for metabolite %02d: Concentration Accuracy, no variance\n',metab_k)
    end

    % derivAccHd
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        barweb(medianDirectDerivAccHd(idxMetab),zeros(size(directDerivDispersion(idxMetab)))); 
        title({'Direct Method','Derivative Accuracy'},'fontsize',18)
        xlabel(sprintf('Metabolite %02d: %s',metab_k,currentMetabName{idxMetab(1)}),'fontsize',18)
        set(gca,'fontsize',18)
        set(gca,'xticklabel',[])
        ylabel('Error','fontsize',18)
        legend(barFuncList ,'Location','EastOutside','fontsize',18)

        fileName = sprintf('%s/bar_noVariance_derivAccHd_metab%02d',plotDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
    catch
        close(h)
        fprintf('Error: Bar plot for metabolite %02d: Derivative Accuracy, no variance\n',metab_k)
    end

    % concRobustness
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        barweb(directConcRobustness(idxMetab),zeros(size(directConcRobustness(idxMetab)))); 
        title({'Direct Method','Concentration Robustness'},'fontsize',18)
        xlabel(sprintf('Metabolite %02d: %s',metab_k,currentMetabName{idxMetab(1)}),'fontsize',18)
        set(gca,'fontsize',18)
        set(gca,'xticklabel',[])
        ylabel('Variability','fontsize',18)
        legend(barFuncList,'Location','EastOutside','fontsize',18)

        fileName = sprintf('%s/bar_concRobustness_metab%02d',plotDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Bar plot for metabolite %02d: Concentration Robustness\n',metab_k)
    end

    % derivRobustness
    try
        set(0,'DefaultFigureVisible','off')
        h = figure('units','normalized','outerposition',[0 0 1 1]);
        barweb(directDerivRobustness(idxMetab),zeros(size(directDerivRobustness(idxMetab)))); 
        title({'Direct Method','Derivative Robustness'},'fontsize',18)
        xlabel(sprintf('Metabolite %02d: %s',metab_k,currentMetabName{idxMetab(1)}),'fontsize',18)
        set(gca,'fontsize',18)
        set(gca,'xticklabel',[])
        ylabel('Variability','fontsize',18)
        legend(barFuncList ,'Location','EastOutside','fontsize',18)

        fileName = sprintf('%s/bar_derivRobustness_metab%02d',plotDir,metab_k);
        print(h,'-dpng','-r600',fileName);
        close(h)
        set(0,'DefaultFigureVisible','on')
    catch
        close(h)
        set(0,'DefaultFigureVisible','on')
        fprintf('Error: Bar plot for metabolite %02d: Derivative Robustness\n',metab_k)
    end

end

clear('numActualMetabs','actualMetabList','numFuncs','barFuncList');
